@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_AUDIO_DRIVER_ALSA
+#ifdef SDL_AUDIO_DRIVER_ALSA
 
 #ifndef SDL_ALSA_NON_BLOCKING
 #define SDL_ALSA_NON_BLOCKING 0
@@ -34,7 +34,7 @@
 /* Allow access to a raw mixing buffer */
 
 #include <sys/types.h>
-#include <signal.h>             /* For kill() */
+#include <signal.h> /* For kill() */
 #include <string.h>
 
 #include "SDL_timer.h"
@@ -46,64 +46,46 @@
 #include "SDL_loadso.h"
 #endif
 
-static int (*ALSA_snd_pcm_open)
-  (snd_pcm_t **, const char *, snd_pcm_stream_t, int);
-static int (*ALSA_snd_pcm_close) (snd_pcm_t * pcm);
-static snd_pcm_sframes_t (*ALSA_snd_pcm_writei)
-  (snd_pcm_t *, const void *, snd_pcm_uframes_t);
-static snd_pcm_sframes_t (*ALSA_snd_pcm_readi)
-  (snd_pcm_t *, void *, snd_pcm_uframes_t);
-static int (*ALSA_snd_pcm_recover) (snd_pcm_t *, int, int);
-static int (*ALSA_snd_pcm_prepare) (snd_pcm_t *);
-static int (*ALSA_snd_pcm_drain) (snd_pcm_t *);
-static const char *(*ALSA_snd_strerror) (int);
-static size_t(*ALSA_snd_pcm_hw_params_sizeof) (void);
-static size_t(*ALSA_snd_pcm_sw_params_sizeof) (void);
-static void (*ALSA_snd_pcm_hw_params_copy)
-  (snd_pcm_hw_params_t *, const snd_pcm_hw_params_t *);
-static int (*ALSA_snd_pcm_hw_params_any) (snd_pcm_t *, snd_pcm_hw_params_t *);
-static int (*ALSA_snd_pcm_hw_params_set_access)
-  (snd_pcm_t *, snd_pcm_hw_params_t *, snd_pcm_access_t);
-static int (*ALSA_snd_pcm_hw_params_set_format)
-  (snd_pcm_t *, snd_pcm_hw_params_t *, snd_pcm_format_t);
-static int (*ALSA_snd_pcm_hw_params_set_channels)
-  (snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int);
-static int (*ALSA_snd_pcm_hw_params_get_channels)
-  (const snd_pcm_hw_params_t *, unsigned int *);
-static int (*ALSA_snd_pcm_hw_params_set_rate_near)
-  (snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int *, int *);
-static int (*ALSA_snd_pcm_hw_params_set_period_size_near)
-  (snd_pcm_t *, snd_pcm_hw_params_t *, snd_pcm_uframes_t *, int *);
-static int (*ALSA_snd_pcm_hw_params_get_period_size)
-  (const snd_pcm_hw_params_t *, snd_pcm_uframes_t *, int *);
-static int (*ALSA_snd_pcm_hw_params_set_periods_min)
-  (snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int *, int *);
-static int (*ALSA_snd_pcm_hw_params_set_periods_first)
-  (snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int *, int *);
-static int (*ALSA_snd_pcm_hw_params_get_periods)
-  (const snd_pcm_hw_params_t *, unsigned int *, int *);
-static int (*ALSA_snd_pcm_hw_params_set_buffer_size_near)
-  (snd_pcm_t *pcm, snd_pcm_hw_params_t *, snd_pcm_uframes_t *);
-static int (*ALSA_snd_pcm_hw_params_get_buffer_size)
-  (const snd_pcm_hw_params_t *, snd_pcm_uframes_t *);
-static int (*ALSA_snd_pcm_hw_params) (snd_pcm_t *, snd_pcm_hw_params_t *);
-static int (*ALSA_snd_pcm_sw_params_current) (snd_pcm_t *,
-                                              snd_pcm_sw_params_t *);
-static int (*ALSA_snd_pcm_sw_params_set_start_threshold)
-  (snd_pcm_t *, snd_pcm_sw_params_t *, snd_pcm_uframes_t);
-static int (*ALSA_snd_pcm_sw_params) (snd_pcm_t *, snd_pcm_sw_params_t *);
-static int (*ALSA_snd_pcm_nonblock) (snd_pcm_t *, int);
+static int (*ALSA_snd_pcm_open)(snd_pcm_t **, const char *, snd_pcm_stream_t, int);
+static int (*ALSA_snd_pcm_close)(snd_pcm_t *pcm);
+static snd_pcm_sframes_t (*ALSA_snd_pcm_writei)(snd_pcm_t *, const void *, snd_pcm_uframes_t);
+static snd_pcm_sframes_t (*ALSA_snd_pcm_readi)(snd_pcm_t *, void *, snd_pcm_uframes_t);
+static int (*ALSA_snd_pcm_recover)(snd_pcm_t *, int, int);
+static int (*ALSA_snd_pcm_prepare)(snd_pcm_t *);
+static int (*ALSA_snd_pcm_drain)(snd_pcm_t *);
+static const char *(*ALSA_snd_strerror)(int);
+static size_t (*ALSA_snd_pcm_hw_params_sizeof)(void);
+static size_t (*ALSA_snd_pcm_sw_params_sizeof)(void);
+static void (*ALSA_snd_pcm_hw_params_copy)(snd_pcm_hw_params_t *, const snd_pcm_hw_params_t *);
+static int (*ALSA_snd_pcm_hw_params_any)(snd_pcm_t *, snd_pcm_hw_params_t *);
+static int (*ALSA_snd_pcm_hw_params_set_access)(snd_pcm_t *, snd_pcm_hw_params_t *, snd_pcm_access_t);
+static int (*ALSA_snd_pcm_hw_params_set_format)(snd_pcm_t *, snd_pcm_hw_params_t *, snd_pcm_format_t);
+static int (*ALSA_snd_pcm_hw_params_set_channels)(snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int);
+static int (*ALSA_snd_pcm_hw_params_get_channels)(const snd_pcm_hw_params_t *, unsigned int *);
+static int (*ALSA_snd_pcm_hw_params_set_rate_near)(snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int *, int *);
+static int (*ALSA_snd_pcm_hw_params_set_period_size_near)(snd_pcm_t *, snd_pcm_hw_params_t *, snd_pcm_uframes_t *, int *);
+static int (*ALSA_snd_pcm_hw_params_get_period_size)(const snd_pcm_hw_params_t *, snd_pcm_uframes_t *, int *);
+static int (*ALSA_snd_pcm_hw_params_set_periods_min)(snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int *, int *);
+static int (*ALSA_snd_pcm_hw_params_set_periods_first)(snd_pcm_t *, snd_pcm_hw_params_t *, unsigned int *, int *);
+static int (*ALSA_snd_pcm_hw_params_get_periods)(const snd_pcm_hw_params_t *, unsigned int *, int *);
+static int (*ALSA_snd_pcm_hw_params_set_buffer_size_near)(snd_pcm_t *pcm, snd_pcm_hw_params_t *, snd_pcm_uframes_t *);
+static int (*ALSA_snd_pcm_hw_params_get_buffer_size)(const snd_pcm_hw_params_t *, snd_pcm_uframes_t *);
+static int (*ALSA_snd_pcm_hw_params)(snd_pcm_t *, snd_pcm_hw_params_t *);
+static int (*ALSA_snd_pcm_sw_params_current)(snd_pcm_t *,
+                                             snd_pcm_sw_params_t *);
+static int (*ALSA_snd_pcm_sw_params_set_start_threshold)(snd_pcm_t *, snd_pcm_sw_params_t *, snd_pcm_uframes_t);
+static int (*ALSA_snd_pcm_sw_params)(snd_pcm_t *, snd_pcm_sw_params_t *);
+static int (*ALSA_snd_pcm_nonblock)(snd_pcm_t *, int);
 static int (*ALSA_snd_pcm_wait)(snd_pcm_t *, int);
-static int (*ALSA_snd_pcm_sw_params_set_avail_min)
-  (snd_pcm_t *, snd_pcm_sw_params_t *, snd_pcm_uframes_t);
+static int (*ALSA_snd_pcm_sw_params_set_avail_min)(snd_pcm_t *, snd_pcm_sw_params_t *, snd_pcm_uframes_t);
 static int (*ALSA_snd_pcm_reset)(snd_pcm_t *);
-static int (*ALSA_snd_device_name_hint) (int, const char *, void ***);
-static char* (*ALSA_snd_device_name_get_hint) (const void *, const char *);
-static int (*ALSA_snd_device_name_free_hint) (void **);
+static int (*ALSA_snd_device_name_hint)(int, const char *, void ***);
+static char *(*ALSA_snd_device_name_get_hint)(const void *, const char *);
+static int (*ALSA_snd_device_name_free_hint)(void **);
 static snd_pcm_sframes_t (*ALSA_snd_pcm_avail)(snd_pcm_t *);
 #ifdef SND_CHMAP_API_VERSION
-static snd_pcm_chmap_t* (*ALSA_snd_pcm_get_chmap) (snd_pcm_t *);
-static int (*ALSA_snd_pcm_chmap_print) (const snd_pcm_chmap_t *map, size_t maxlen, char *buf);
+static snd_pcm_chmap_t *(*ALSA_snd_pcm_get_chmap)(snd_pcm_t *);
+static int (*ALSA_snd_pcm_chmap_print)(const snd_pcm_chmap_t *map, size_t maxlen, char *buf);
 #endif
 
 #ifdef SDL_AUDIO_DRIVER_ALSA_DYNAMIC
@@ -113,11 +95,10 @@ static int (*ALSA_snd_pcm_chmap_print) (const snd_pcm_chmap_t *map, size_t maxle
 static const char *alsa_library = SDL_AUDIO_DRIVER_ALSA_DYNAMIC;
 static void *alsa_handle = NULL;
 
-static int
-load_alsa_sym(const char *fn, void **addr)
+static int load_alsa_sym(const char *fn, void **addr)
 {
     *addr = SDL_LoadFunction(alsa_handle, fn);
-    if (*addr == NULL) {
+    if (!*addr) {
         /* Don't call SDL_SetError(): SDL_LoadFunction already did. */
         return 0;
     }
@@ -126,14 +107,14 @@ load_alsa_sym(const char *fn, void **addr)
 }
 
 /* cast funcs to char* first, to please GCC's strict aliasing rules. */
-#define SDL_ALSA_SYM(x) \
-    if (!load_alsa_sym(#x, (void **) (char *) &ALSA_##x)) return -1
+#define SDL_ALSA_SYM(x)                                 \
+    if (!load_alsa_sym(#x, (void **)(char *)&ALSA_##x)) \
+    return -1
 #else
 #define SDL_ALSA_SYM(x) ALSA_##x = x
 #endif
 
-static int
-load_alsa_syms(void)
+static int load_alsa_syms(void)
 {
     SDL_ALSA_SYM(snd_pcm_open);
     SDL_ALSA_SYM(snd_pcm_close);
@@ -183,22 +164,20 @@ load_alsa_syms(void)
 
 #ifdef SDL_AUDIO_DRIVER_ALSA_DYNAMIC
 
-static void
-UnloadALSALibrary(void)
+static void UnloadALSALibrary(void)
 {
-    if (alsa_handle != NULL) {
+    if (alsa_handle) {
         SDL_UnloadObject(alsa_handle);
         alsa_handle = NULL;
     }
 }
 
-static int
-LoadALSALibrary(void)
+static int LoadALSALibrary(void)
 {
     int retval = 0;
-    if (alsa_handle == NULL) {
+    if (!alsa_handle) {
         alsa_handle = SDL_LoadObject(alsa_library);
-        if (alsa_handle == NULL) {
+        if (!alsa_handle) {
             retval = -1;
             /* Don't call SDL_SetError(): SDL_LoadObject already did. */
         } else {
@@ -213,13 +192,11 @@ LoadALSALibrary(void)
 
 #else
 
-static void
-UnloadALSALibrary(void)
+static void UnloadALSALibrary(void)
 {
 }
 
-static int
-LoadALSALibrary(void)
+static int LoadALSALibrary(void)
 {
     load_alsa_syms();
     return 0;
@@ -227,18 +204,17 @@ LoadALSALibrary(void)
 
 #endif /* SDL_AUDIO_DRIVER_ALSA_DYNAMIC */
 
-static const char *
-get_audio_device(void *handle, const int channels)
+static const char *get_audio_device(void *handle, const int channels)
 {
     const char *device;
 
-    if (handle != NULL) {
-        return (const char *) handle;
+    if (handle) {
+        return (const char *)handle;
     }
 
     /* !!! FIXME: we also check "SDL_AUDIO_DEVICE_NAME" at the higher level. */
-    device = SDL_getenv("AUDIODEV");    /* Is there a standard variable name? */
-    if (device != NULL) {
+    device = SDL_getenv("AUDIODEV"); /* Is there a standard variable name? */
+    if (device) {
         return device;
     }
 
@@ -251,49 +227,50 @@ get_audio_device(void *handle, const int channels)
     return "default";
 }
 
-
 /* This function waits until it is possible to write a full sound buffer */
-static void
-ALSA_WaitDevice(_THIS)
+static void ALSA_WaitDevice(_THIS)
 {
 #if SDL_ALSA_NON_BLOCKING
-    const snd_pcm_sframes_t needed = (snd_pcm_sframes_t) this->spec.samples;
+    const snd_pcm_sframes_t needed = (snd_pcm_sframes_t)this->spec.samples;
     while (SDL_AtomicGet(&this->enabled)) {
         const snd_pcm_sframes_t rc = ALSA_snd_pcm_avail(this->hidden->pcm_handle);
         if ((rc < 0) && (rc != -EAGAIN)) {
             /* Hmm, not much we can do - abort */
             fprintf(stderr, "ALSA snd_pcm_avail failed (unrecoverable): %s\n",
-                        ALSA_snd_strerror(rc));
+                    ALSA_snd_strerror(rc));
             SDL_OpenedAudioDeviceDisconnected(this);
             return;
         } else if (rc < needed) {
             const Uint32 delay = ((needed - (SDL_max(rc, 0))) * 1000) / this->spec.freq;
             SDL_Delay(SDL_max(delay, 10));
         } else {
-            break;  /* ready to go! */
+            break; /* ready to go! */
         }
     }
 #endif
 }
 
-
 /* !!! FIXME: is there a channel swizzler in alsalib instead? */
 /*
  * https://bugzilla.libsdl.org/show_bug.cgi?id=110
  * "For Linux ALSA, this is FL-FR-RL-RR-C-LFE
  *  and for Windows DirectX [and CoreAudio], this is FL-FR-C-LFE-RL-RR"
  */
-#define SWIZ6(T) \
-static void swizzle_alsa_channels_6_##T(void *buffer, const Uint32 bufferlen) { \
-    T *ptr = (T *) buffer; \
-    Uint32 i; \
-    for (i = 0; i < bufferlen; i++, ptr += 6) { \
-        T tmp; \
-        tmp = ptr[2]; ptr[2] = ptr[4]; ptr[4] = tmp; \
-        tmp = ptr[3]; ptr[3] = ptr[5]; ptr[5] = tmp; \
-    } \
-}
-
+#define SWIZ6(T)                                                                  \
+    static void swizzle_alsa_channels_6_##T(void *buffer, const Uint32 bufferlen) \
+    {                                                                             \
+        T *ptr = (T *)buffer;                                                     \
+        Uint32 i;                                                                 \
+        for (i = 0; i < bufferlen; i++, ptr += 6) {                               \
+            T tmp;                                                                \
+            tmp = ptr[2];                                                         \
+            ptr[2] = ptr[4];                                                      \
+            ptr[4] = tmp;                                                         \
+            tmp = ptr[3];                                                         \
+            ptr[3] = ptr[5];                                                      \
+            ptr[5] = tmp;                                                         \
+        }                                                                         \
+    }
 
 /* !!! FIXME: is there a channel swizzler in alsalib instead? */
 /* !!! FIXME: this screams for a SIMD shuffle operation. */
@@ -302,31 +279,32 @@ static void swizzle_alsa_channels_6_##T(void *buffer, const Uint32 bufferlen) {
  * For Linux ALSA, this appears to be FL-FR-RL-RR-C-LFE-SL-SR
  *  and for Windows DirectX [and CoreAudio], this is FL-FR-C-LFE-SL-SR-RL-RR"
  */
-#define SWIZ8(T) \
-static void swizzle_alsa_channels_8_##T(void *buffer, const Uint32 bufferlen) { \
-    T *ptr = (T *) buffer; \
-    Uint32 i; \
-    for (i = 0; i < bufferlen; i++, ptr += 6) { \
-        const T center = ptr[2]; \
-        const T subwoofer = ptr[3]; \
-        const T side_left = ptr[4]; \
-        const T side_right = ptr[5]; \
-        const T rear_left = ptr[6]; \
-        const T rear_right = ptr[7]; \
-        ptr[2] = rear_left; \
-        ptr[3] = rear_right; \
-        ptr[4] = center; \
-        ptr[5] = subwoofer; \
-        ptr[6] = side_left; \
-        ptr[7] = side_right; \
-    } \
-}
+#define SWIZ8(T)                                                                  \
+    static void swizzle_alsa_channels_8_##T(void *buffer, const Uint32 bufferlen) \
+    {                                                                             \
+        T *ptr = (T *)buffer;                                                     \
+        Uint32 i;                                                                 \
+        for (i = 0; i < bufferlen; i++, ptr += 6) {                               \
+            const T center = ptr[2];                                              \
+            const T subwoofer = ptr[3];                                           \
+            const T side_left = ptr[4];                                           \
+            const T side_right = ptr[5];                                          \
+            const T rear_left = ptr[6];                                           \
+            const T rear_right = ptr[7];                                          \
+            ptr[2] = rear_left;                                                   \
+            ptr[3] = rear_right;                                                  \
+            ptr[4] = center;                                                      \
+            ptr[5] = subwoofer;                                                   \
+            ptr[6] = side_left;                                                   \
+            ptr[7] = side_right;                                                  \
+        }                                                                         \
+    }
 
 #define CHANNEL_SWIZZLE(x) \
-    x(Uint64) \
-    x(Uint32) \
-    x(Uint16) \
-    x(Uint8)
+    x(Uint64)              \
+        x(Uint32)          \
+            x(Uint16)      \
+                x(Uint8)
 
 CHANNEL_SWIZZLE(SWIZ6)
 CHANNEL_SWIZZLE(SWIZ8)
@@ -335,53 +313,59 @@ CHANNEL_SWIZZLE(SWIZ8)
 #undef SWIZ6
 #undef SWIZ8
 
-
 /*
  * Called right before feeding this->hidden->mixbuf to the hardware. Swizzle
  *  channels from Windows/Mac order to the format alsalib will want.
  */
-static void
-swizzle_alsa_channels(_THIS, void *buffer, Uint32 bufferlen)
+static void swizzle_alsa_channels(_THIS, void *buffer, Uint32 bufferlen)
 {
     switch (this->spec.channels) {
-        #define CHANSWIZ(chans) \
-        case chans: \
-            switch ((this->spec.format & (0xFF))) { \
-                case 8: swizzle_alsa_channels_##chans##_Uint8(buffer, bufferlen); break; \
-                case 16: swizzle_alsa_channels_##chans##_Uint16(buffer, bufferlen); break; \
-                case 32: swizzle_alsa_channels_##chans##_Uint32(buffer, bufferlen); break; \
-                case 64: swizzle_alsa_channels_##chans##_Uint64(buffer, bufferlen); break; \
-                default: SDL_assert(!"unhandled bitsize"); break; \
-            } \
-            return;
+#define CHANSWIZ(chans)                                                \
+    case chans:                                                        \
+        switch ((this->spec.format & (0xFF))) {                        \
+        case 8:                                                        \
+            swizzle_alsa_channels_##chans##_Uint8(buffer, bufferlen);  \
+            break;                                                     \
+        case 16:                                                       \
+            swizzle_alsa_channels_##chans##_Uint16(buffer, bufferlen); \
+            break;                                                     \
+        case 32:                                                       \
+            swizzle_alsa_channels_##chans##_Uint32(buffer, bufferlen); \
+            break;                                                     \
+        case 64:                                                       \
+            swizzle_alsa_channels_##chans##_Uint64(buffer, bufferlen); \
+            break;                                                     \
+        default:                                                       \
+            SDL_assert(!"unhandled bitsize");                          \
+            break;                                                     \
+        }                                                              \
+        return;
 
         CHANSWIZ(6);
         CHANSWIZ(8);
-        #undef CHANSWIZ
-        default: break;
+#undef CHANSWIZ
+    default:
+        break;
     }
 }
 
 #ifdef SND_CHMAP_API_VERSION
 /* Some devices have the right channel map, no swizzling necessary */
-static void
-no_swizzle(_THIS, void *buffer, Uint32 bufferlen)
+static void no_swizzle(_THIS, void *buffer, Uint32 bufferlen)
 {
 }
 #endif /* SND_CHMAP_API_VERSION */
 
-
-static void
-ALSA_PlayDevice(_THIS)
+static void ALSA_PlayDevice(_THIS)
 {
-    const Uint8 *sample_buf = (const Uint8 *) this->hidden->mixbuf;
+    const Uint8 *sample_buf = (const Uint8 *)this->hidden->mixbuf;
     const int frame_size = ((SDL_AUDIO_BITSIZE(this->spec.format)) / 8) *
-                                this->spec.channels;
-    snd_pcm_uframes_t frames_left = ((snd_pcm_uframes_t) this->spec.samples);
+                           this->spec.channels;
+    snd_pcm_uframes_t frames_left = ((snd_pcm_uframes_t)this->spec.samples);
 
     this->hidden->swizzle_func(this, this->hidden->mixbuf, frames_left);
 
-    while ( frames_left > 0 && SDL_AtomicGet(&this->enabled) ) {
+    while (frames_left > 0 && SDL_AtomicGet(&this->enabled)) {
         int status = ALSA_snd_pcm_writei(this->hidden->pcm_handle,
                                          sample_buf, frames_left);
 
@@ -395,14 +379,14 @@ ALSA_PlayDevice(_THIS)
             status = ALSA_snd_pcm_recover(this->hidden->pcm_handle, status, 0);
             if (status < 0) {
                 /* Hmm, not much we can do - abort */
-                fprintf(stderr, "ALSA write failed (unrecoverable): %s\n",
-                        ALSA_snd_strerror(status));
+                SDL_LogError(SDL_LOG_CATEGORY_AUDIO,
+                             "ALSA write failed (unrecoverable): %s\n",
+                             ALSA_snd_strerror(status));
                 SDL_OpenedAudioDeviceDisconnected(this);
                 return;
             }
             continue;
-        }
-        else if (status == 0) {
+        } else if (status == 0) {
             /* No frames were written (no available space in pcm device).
                Allow other threads to catch up. */
             Uint32 delay = (frames_left / 2 * 1000) / this->spec.freq;
@@ -414,41 +398,39 @@ ALSA_PlayDevice(_THIS)
     }
 }
 
-static Uint8 *
-ALSA_GetDeviceBuf(_THIS)
+static Uint8 *ALSA_GetDeviceBuf(_THIS)
 {
-    return (this->hidden->mixbuf);
+    return this->hidden->mixbuf;
 }
 
-static int
-ALSA_CaptureFromDevice(_THIS, void *buffer, int buflen)
+static int ALSA_CaptureFromDevice(_THIS, void *buffer, int buflen)
 {
-    Uint8 *sample_buf = (Uint8 *) buffer;
+    Uint8 *sample_buf = (Uint8 *)buffer;
     const int frame_size = ((SDL_AUDIO_BITSIZE(this->spec.format)) / 8) *
-                                this->spec.channels;
+                           this->spec.channels;
     const int total_frames = buflen / frame_size;
     snd_pcm_uframes_t frames_left = total_frames;
     snd_pcm_uframes_t wait_time = frame_size / 2;
 
     SDL_assert((buflen % frame_size) == 0);
 
-    while ( frames_left > 0 && SDL_AtomicGet(&this->enabled) ) {
+    while (frames_left > 0 && SDL_AtomicGet(&this->enabled)) {
         int status;
 
         status = ALSA_snd_pcm_readi(this->hidden->pcm_handle,
-                                        sample_buf, frames_left);
+                                    sample_buf, frames_left);
 
         if (status == -EAGAIN) {
             ALSA_snd_pcm_wait(this->hidden->pcm_handle, wait_time);
             status = 0;
-        }
-        else if (status < 0) {
+        } else if (status < 0) {
             /*printf("ALSA: capture error %d\n", status);*/
             status = ALSA_snd_pcm_recover(this->hidden->pcm_handle, status, 0);
             if (status < 0) {
                 /* Hmm, not much we can do - abort */
-                fprintf(stderr, "ALSA read failed (unrecoverable): %s\n",
-                        ALSA_snd_strerror(status));
+                SDL_LogError(SDL_LOG_CATEGORY_AUDIO,
+                             "ALSA read failed (unrecoverable): %s\n",
+                             ALSA_snd_strerror(status));
                 return -1;
             }
             continue;
@@ -464,14 +446,12 @@ ALSA_CaptureFromDevice(_THIS, void *buffer, int buflen)
     return (total_frames - frames_left) * frame_size;
 }
 
-static void
-ALSA_FlushCapture(_THIS)
+static void ALSA_FlushCapture(_THIS)
 {
     ALSA_snd_pcm_reset(this->hidden->pcm_handle);
 }
 
-static void
-ALSA_CloseDevice(_THIS)
+static void ALSA_CloseDevice(_THIS)
 {
     if (this->hidden->pcm_handle) {
         /* Wait for the submitted audio to drain
@@ -486,8 +466,7 @@ ALSA_CloseDevice(_THIS)
     SDL_free(this->hidden);
 }
 
-static int
-ALSA_set_buffer_size(_THIS, snd_pcm_hw_params_t *params)
+static int ALSA_set_buffer_size(_THIS, snd_pcm_hw_params_t *params)
 {
     int status;
     snd_pcm_hw_params_t *hwparams;
@@ -501,49 +480,48 @@ ALSA_set_buffer_size(_THIS, snd_pcm_hw_params_t *params)
     /* Attempt to match the period size to the requested buffer size */
     persize = this->spec.samples;
     status = ALSA_snd_pcm_hw_params_set_period_size_near(
-                this->hidden->pcm_handle, hwparams, &persize, NULL);
-    if ( status < 0 ) {
-        return(-1);
+        this->hidden->pcm_handle, hwparams, &persize, NULL);
+    if (status < 0) {
+        return -1;
     }
 
     /* Need to at least double buffer */
     periods = 2;
     status = ALSA_snd_pcm_hw_params_set_periods_min(
-                this->hidden->pcm_handle, hwparams, &periods, NULL);
-    if ( status < 0 ) {
-        return(-1);
+        this->hidden->pcm_handle, hwparams, &periods, NULL);
+    if (status < 0) {
+        return -1;
     }
 
     status = ALSA_snd_pcm_hw_params_set_periods_first(
-                this->hidden->pcm_handle, hwparams, &periods, NULL);
-    if ( status < 0 ) {
-        return(-1);
+        this->hidden->pcm_handle, hwparams, &periods, NULL);
+    if (status < 0) {
+        return -1;
     }
 
     /* "set" the hardware with the desired parameters */
     status = ALSA_snd_pcm_hw_params(this->hidden->pcm_handle, hwparams);
-    if ( status < 0 ) {
-        return(-1);
+    if (status < 0) {
+        return -1;
     }
 
     this->spec.samples = persize;
 
     /* This is useful for debugging */
-    if ( SDL_getenv("SDL_AUDIO_ALSA_DEBUG") ) {
+    if (SDL_getenv("SDL_AUDIO_ALSA_DEBUG")) {
         snd_pcm_uframes_t bufsize;
 
         ALSA_snd_pcm_hw_params_get_buffer_size(hwparams, &bufsize);
 
-        fprintf(stderr,
-            "ALSA: period size = %ld, periods = %u, buffer size = %lu\n",
-            persize, periods, bufsize);
+        SDL_LogError(SDL_LOG_CATEGORY_AUDIO,
+                     "ALSA: period size = %ld, periods = %u, buffer size = %lu\n",
+                     persize, periods, bufsize);
     }
 
-    return(0);
+    return 0;
 }
 
-static int
-ALSA_OpenDevice(_THIS, const char *devname)
+static int ALSA_OpenDevice(_THIS, const char *devname)
 {
     int status = 0;
     SDL_bool iscapture = this->iscapture;
@@ -560,9 +538,8 @@ ALSA_OpenDevice(_THIS, const char *devname)
 #endif
 
     /* Initialize all variables that we clean on shutdown */
-    this->hidden = (struct SDL_PrivateAudioData *)
-        SDL_malloc((sizeof *this->hidden));
-    if (this->hidden == NULL) {
+    this->hidden = (struct SDL_PrivateAudioData *)SDL_malloc(sizeof(*this->hidden));
+    if (!this->hidden) {
         return SDL_OutOfMemory();
     }
     SDL_zerop(this->hidden);
@@ -570,13 +547,12 @@ ALSA_OpenDevice(_THIS, const char *devname)
     /* Open the audio device */
     /* Name of device should depend on # channels in spec */
     status = ALSA_snd_pcm_open(&pcm_handle,
-                get_audio_device(this->handle, this->spec.channels),
-                iscapture ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK,
-                SND_PCM_NONBLOCK);
+                               get_audio_device(this->handle, this->spec.channels),
+                               iscapture ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK,
+                               SND_PCM_NONBLOCK);
 
     if (status < 0) {
-        return SDL_SetError("ALSA: Couldn't open audio device: %s",
-                            ALSA_snd_strerror(status));
+        return SDL_SetError("ALSA: Couldn't open audio device: %s", ALSA_snd_strerror(status));
     }
 
     this->hidden->pcm_handle = pcm_handle;
@@ -585,16 +561,14 @@ ALSA_OpenDevice(_THIS, const char *devname)
     snd_pcm_hw_params_alloca(&hwparams);
     status = ALSA_snd_pcm_hw_params_any(pcm_handle, hwparams);
     if (status < 0) {
-        return SDL_SetError("ALSA: Couldn't get hardware config: %s",
-                            ALSA_snd_strerror(status));
+        return SDL_SetError("ALSA: Couldn't get hardware config: %s", ALSA_snd_strerror(status));
     }
 
     /* SDL only uses interleaved sample output */
     status = ALSA_snd_pcm_hw_params_set_access(pcm_handle, hwparams,
                                                SND_PCM_ACCESS_RW_INTERLEAVED);
     if (status < 0) {
-        return SDL_SetError("ALSA: Couldn't set interleaved access: %s",
-                     ALSA_snd_strerror(status));
+        return SDL_SetError("ALSA: Couldn't set interleaved access: %s", ALSA_snd_strerror(status));
     }
 
     /* Try for a closest match on audio format */
@@ -676,8 +650,7 @@ ALSA_OpenDevice(_THIS, const char *devname)
     status = ALSA_snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams,
                                                   &rate, NULL);
     if (status < 0) {
-        return SDL_SetError("ALSA: Couldn't set audio frequency: %s",
-                            ALSA_snd_strerror(status));
+        return SDL_SetError("ALSA: Couldn't set audio frequency: %s", ALSA_snd_strerror(status));
     }
     this->spec.freq = rate;
 
@@ -691,24 +664,20 @@ ALSA_OpenDevice(_THIS, const char *devname)
     snd_pcm_sw_params_alloca(&swparams);
     status = ALSA_snd_pcm_sw_params_current(pcm_handle, swparams);
     if (status < 0) {
-        return SDL_SetError("ALSA: Couldn't get software config: %s",
-                            ALSA_snd_strerror(status));
+        return SDL_SetError("ALSA: Couldn't get software config: %s", ALSA_snd_strerror(status));
     }
     status = ALSA_snd_pcm_sw_params_set_avail_min(pcm_handle, swparams, this->spec.samples);
     if (status < 0) {
-        return SDL_SetError("Couldn't set minimum available samples: %s",
-                            ALSA_snd_strerror(status));
+        return SDL_SetError("Couldn't set minimum available samples: %s", ALSA_snd_strerror(status));
     }
     status =
         ALSA_snd_pcm_sw_params_set_start_threshold(pcm_handle, swparams, 1);
     if (status < 0) {
-        return SDL_SetError("ALSA: Couldn't set start threshold: %s",
-                            ALSA_snd_strerror(status));
+        return SDL_SetError("ALSA: Couldn't set start threshold: %s", ALSA_snd_strerror(status));
     }
     status = ALSA_snd_pcm_sw_params(pcm_handle, swparams);
     if (status < 0) {
-        return SDL_SetError("Couldn't set software audio parameters: %s",
-                            ALSA_snd_strerror(status));
+        return SDL_SetError("Couldn't set software audio parameters: %s", ALSA_snd_strerror(status));
     }
 
     /* Calculate the final parameters for this audio specification */
@@ -717,18 +686,18 @@ ALSA_OpenDevice(_THIS, const char *devname)
     /* Allocate mixing buffer */
     if (!iscapture) {
         this->hidden->mixlen = this->spec.size;
-        this->hidden->mixbuf = (Uint8 *) SDL_malloc(this->hidden->mixlen);
-        if (this->hidden->mixbuf == NULL) {
+        this->hidden->mixbuf = (Uint8 *)SDL_malloc(this->hidden->mixlen);
+        if (!this->hidden->mixbuf) {
             return SDL_OutOfMemory();
         }
         SDL_memset(this->hidden->mixbuf, this->spec.silence, this->hidden->mixlen);
     }
 
-    #if !SDL_ALSA_NON_BLOCKING
+#if !SDL_ALSA_NON_BLOCKING
     if (!iscapture) {
         ALSA_snd_pcm_nonblock(pcm_handle, 0);
     }
-    #endif
+#endif
 
     /* We're ready to rock and roll. :-) */
     return 0;
@@ -741,10 +710,9 @@ typedef struct ALSA_Device
     struct ALSA_Device *next;
 } ALSA_Device;
 
-static void
-add_device(const int iscapture, const char *name, void *hint, ALSA_Device **pSeen)
+static void add_device(const int iscapture, const char *name, void *hint, ALSA_Device **pSeen)
 {
-    ALSA_Device *dev = SDL_malloc(sizeof (ALSA_Device));
+    ALSA_Device *dev = SDL_malloc(sizeof(ALSA_Device));
     char *desc;
     char *handle = NULL;
     char *ptr;
@@ -764,7 +732,7 @@ add_device(const int iscapture, const char *name, void *hint, ALSA_Device **pSee
             return;
         }
     } else {
-        desc = (char *) name;
+        desc = (char *)name;
     }
 
     SDL_assert(name != NULL);
@@ -772,7 +740,8 @@ add_device(const int iscapture, const char *name, void *hint, ALSA_Device **pSee
     /* some strings have newlines, like "HDA NVidia, HDMI 0\nHDMI Audio Output".
        just chop the extra lines off, this seems to get a reasonable device
        name without extra details. */
-    if ((ptr = SDL_strchr(desc, '\n')) != NULL) {
+    ptr = SDL_strchr(desc, '\n');
+    if (ptr) {
         *ptr = '\0';
     }
 
@@ -792,19 +761,18 @@ add_device(const int iscapture, const char *name, void *hint, ALSA_Device **pSee
      * enumeration time
      */
     SDL_AddAudioDevice(iscapture, desc, NULL, handle);
-    if (hint)
+    if (hint) {
         free(desc);
+    }
     dev->name = handle;
     dev->iscapture = iscapture;
     dev->next = *pSeen;
     *pSeen = dev;
 }
 
-
 static ALSA_Device *hotplug_devices = NULL;
 
-static void
-ALSA_HotplugIteration(void)
+static void ALSA_HotplugIteration(void)
 {
     void **hints = NULL;
     ALSA_Device *dev;
@@ -819,7 +787,7 @@ ALSA_HotplugIteration(void)
         int bestmatch = 0xFFFF;
         size_t match_len = 0;
         int defaultdev = -1;
-        static const char * const prefixes[] = {
+        static const char *const prefixes[] = {
             "hw:", "sysdefault:", "default:", NULL
         };
 
@@ -862,7 +830,7 @@ ALSA_HotplugIteration(void)
 
             /* if we didn't find a device name prefix we like at all... */
             if ((!match) && (defaultdev != i)) {
-                continue;  /* ...skip anything that isn't the default device. */
+                continue; /* ...skip anything that isn't the default device. */
             }
 
             name = ALSA_snd_device_name_get_hint(hints[i], "NAME");
@@ -873,8 +841,8 @@ ALSA_HotplugIteration(void)
             /* only want physical hardware interfaces */
             if (!match || (SDL_strncmp(name, match, match_len) == 0)) {
                 char *ioid = ALSA_snd_device_name_get_hint(hints[i], "IOID");
-                const SDL_bool isoutput = (ioid == NULL) || (SDL_strcmp(ioid, "Output") == 0);
-                const SDL_bool isinput = (ioid == NULL) || (SDL_strcmp(ioid, "Input") == 0);
+                const SDL_bool isoutput = (!ioid) || (SDL_strcmp(ioid, "Output") == 0);
+                const SDL_bool isinput = (!ioid) || (SDL_strcmp(ioid, "Input") == 0);
                 SDL_bool have_output = SDL_FALSE;
                 SDL_bool have_input = SDL_FALSE;
 
@@ -888,7 +856,7 @@ ALSA_HotplugIteration(void)
                 prev = NULL;
                 for (dev = unseen; dev; dev = next) {
                     next = dev->next;
-                    if ( (SDL_strcmp(dev->name, name) == 0) && (((isinput) && dev->iscapture) || ((isoutput) && !dev->iscapture)) ) {
+                    if ((SDL_strcmp(dev->name, name) == 0) && (((isinput) && dev->iscapture) || ((isoutput) && !dev->iscapture))) {
                         if (prev) {
                             prev->next = next;
                         } else {
@@ -896,8 +864,12 @@ ALSA_HotplugIteration(void)
                         }
                         dev->next = seen;
                         seen = dev;
-                        if (isinput) have_input = SDL_TRUE;
-                        if (isoutput) have_output = SDL_TRUE;
+                        if (isinput) {
+                            have_input = SDL_TRUE;
+                        }
+                        if (isoutput) {
+                            have_output = SDL_TRUE;
+                        }
                     } else {
                         prev = dev;
                     }
@@ -916,7 +888,7 @@ ALSA_HotplugIteration(void)
 
         ALSA_snd_device_name_free_hint(hints);
 
-        hotplug_devices = seen;   /* now we have a known-good list of attached devices. */
+        hotplug_devices = seen; /* now we have a known-good list of attached devices. */
 
         /* report anything still in unseen as removed. */
         for (dev = unseen; dev; dev = next) {
@@ -933,8 +905,7 @@ ALSA_HotplugIteration(void)
 static SDL_atomic_t ALSA_hotplug_shutdown;
 static SDL_Thread *ALSA_hotplug_thread;
 
-static int SDLCALL
-ALSA_HotplugThread(void *arg)
+static int SDLCALL ALSA_HotplugThread(void *arg)
 {
     SDL_SetThreadPriority(SDL_THREAD_PRIORITY_LOW);
 
@@ -945,17 +916,16 @@ ALSA_HotplugThread(void *arg)
             SDL_Delay(100);
         }
 
-        ALSA_HotplugIteration();  /* run the check. */
+        ALSA_HotplugIteration(); /* run the check. */
     }
 
     return 0;
 }
 #endif
 
-static void
-ALSA_DetectDevices(void)
+static void ALSA_DetectDevices(void)
 {
-    ALSA_HotplugIteration();  /* run once now before a thread continues to check. */
+    ALSA_HotplugIteration(); /* run once now before a thread continues to check. */
 
 #if SDL_ALSA_HOTPLUG_THREAD
     SDL_AtomicSet(&ALSA_hotplug_shutdown, 0);
@@ -964,14 +934,13 @@ ALSA_DetectDevices(void)
 #endif
 }
 
-static void
-ALSA_Deinitialize(void)
+static void ALSA_Deinitialize(void)
 {
     ALSA_Device *dev;
     ALSA_Device *next;
 
 #if SDL_ALSA_HOTPLUG_THREAD
-    if (ALSA_hotplug_thread != NULL) {
+    if (ALSA_hotplug_thread) {
         SDL_AtomicSet(&ALSA_hotplug_shutdown, 1);
         SDL_WaitThread(ALSA_hotplug_thread, NULL);
         ALSA_hotplug_thread = NULL;
@@ -990,8 +959,7 @@ ALSA_Deinitialize(void)
     UnloadALSALibrary();
 }
 
-static SDL_bool
-ALSA_Init(SDL_AudioDriverImpl * impl)
+static SDL_bool ALSA_Init(SDL_AudioDriverImpl *impl)
 {
     if (LoadALSALibrary() < 0) {
         return SDL_FALSE;
@@ -1011,10 +979,9 @@ ALSA_Init(SDL_AudioDriverImpl * impl)
     impl->HasCaptureSupport = SDL_TRUE;
     impl->SupportsNonPow2Samples = SDL_TRUE;
 
-    return SDL_TRUE;   /* this audio target is available. */
+    return SDL_TRUE; /* this audio target is available. */
 }
 
-
 AudioBootStrap ALSA_bootstrap = {
     "alsa", "ALSA PCM audio", ALSA_Init, SDL_FALSE
 };
