@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -26,12 +26,11 @@
 #include "../SDL_sysaudio.h"
 
 #if !defined(__IPHONEOS__)
-#define MACOSX_COREAUDIO 1
+#define MACOSX_COREAUDIO
 #endif
 
-#if MACOSX_COREAUDIO
+#ifdef MACOSX_COREAUDIO
 #include <CoreAudio/CoreAudio.h>
-#include <CoreServices/CoreServices.h>
 #else
 #import <AVFoundation/AVFoundation.h>
 #import <UIKit/UIApplication.h>
@@ -40,13 +39,22 @@
 #include <AudioToolbox/AudioToolbox.h>
 #include <AudioUnit/AudioUnit.h>
 
+/* Things named "Master" were renamed to "Main" in macOS 12.0's SDK. */
+#ifdef MACOSX_COREAUDIO
+#include <AvailabilityMacros.h>
+#ifndef MAC_OS_VERSION_12_0
+#define kAudioObjectPropertyElementMain kAudioObjectPropertyElementMaster
+#endif
+#endif
+
 /* Hidden "this" pointer for the audio functions */
-#define _THIS   SDL_AudioDevice *this
+#define _THIS SDL_AudioDevice *this
 
 struct SDL_PrivateAudioData
 {
     SDL_Thread *thread;
     AudioQueueRef audioQueue;
+    int numAudioBuffers;
     AudioQueueBufferRef *audioBuffer;
     void *buffer;
     UInt32 bufferOffset;
@@ -54,9 +62,9 @@ struct SDL_PrivateAudioData
     AudioStreamBasicDescription strdesc;
     SDL_sem *ready_semaphore;
     char *thread_error;
-    SDL_atomic_t shutdown;
-#if MACOSX_COREAUDIO
+#ifdef MACOSX_COREAUDIO
     AudioDeviceID deviceID;
+    SDL_atomic_t device_change_flag;
 #else
     SDL_bool interrupted;
     CFTypeRef interruption_listener;
