@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -39,7 +39,7 @@
 #include "../../events/SDL_events_c.h"
 #include "SDL_evdev_kbd_default_keyaccmap.h"
 
-typedef void (fn_handler_fn)(SDL_EVDEV_keyboard_state *kbd);
+typedef void(fn_handler_fn)(SDL_EVDEV_keyboard_state *kbd);
 
 /*
  * Keyboard State
@@ -51,14 +51,14 @@ struct SDL_EVDEV_keyboard_state
     int keyboard_fd;
     unsigned long old_kbd_mode;
     unsigned short **key_maps;
-    keymap_t* key_map;
-    keyboard_info_t* kbInfo;
-    unsigned char shift_down[4];        /* shift state counters.. */
+    keymap_t *key_map;
+    keyboard_info_t *kbInfo;
+    unsigned char shift_down[4]; /* shift state counters.. */
     SDL_bool dead_key_next;
-    int npadch;                    /* -1 or number assembled on pad */
+    int npadch; /* -1 or number assembled on pad */
     accentmap_t *accents;
     unsigned int diacr;
-    SDL_bool rep;                    /* flag telling character repeat */
+    SDL_bool rep; /* flag telling character repeat */
     unsigned char lockstate;
     unsigned char ledflagstate;
     char shift_state;
@@ -68,51 +68,51 @@ struct SDL_EVDEV_keyboard_state
 
 static int SDL_EVDEV_kbd_load_keymaps(SDL_EVDEV_keyboard_state *kbd)
 {
-    return (ioctl(kbd->keyboard_fd, GIO_KEYMAP, kbd->key_map) >= 0);
+    return ioctl(kbd->keyboard_fd, GIO_KEYMAP, kbd->key_map) >= 0;
 }
 
-static SDL_EVDEV_keyboard_state * kbd_cleanup_state = NULL;
+static SDL_EVDEV_keyboard_state *kbd_cleanup_state = NULL;
 static int kbd_cleanup_sigactions_installed = 0;
 static int kbd_cleanup_atexit_installed = 0;
 
 static struct sigaction old_sigaction[NSIG];
 
-static int fatal_signals[] =
-{
+static int fatal_signals[] = {
     /* Handlers for SIGTERM and SIGINT are installed in SDL_QuitInit. */
-    SIGHUP,  SIGQUIT, SIGILL,  SIGABRT,
-    SIGFPE,  SIGSEGV, SIGPIPE, SIGBUS,
+    SIGHUP, SIGQUIT, SIGILL, SIGABRT,
+    SIGFPE, SIGSEGV, SIGPIPE, SIGBUS,
     SIGSYS
 };
 
 static void kbd_cleanup(void)
 {
     struct mouse_info mData;
-    SDL_EVDEV_keyboard_state* kbd = kbd_cleanup_state;
-    if (kbd == NULL) {
+    SDL_EVDEV_keyboard_state *kbd = kbd_cleanup_state;
+    if (!kbd) {
         return;
     }
     kbd_cleanup_state = NULL;
     SDL_zero(mData);
     mData.operation = MOUSE_SHOW;
     ioctl(kbd->keyboard_fd, KDSKBMODE, kbd->old_kbd_mode);
-    if (kbd->keyboard_fd != kbd->console_fd) close(kbd->keyboard_fd);
+    if (kbd->keyboard_fd != kbd->console_fd) {
+        close(kbd->keyboard_fd);
+    }
     ioctl(kbd->console_fd, CONS_SETKBD, (unsigned long)(kbd->kbInfo->kb_index));
     ioctl(kbd->console_fd, CONS_MOUSECTL, &mData);
 }
 
-void
-SDL_EVDEV_kbd_reraise_signal(int sig)
+void SDL_EVDEV_kbd_reraise_signal(int sig)
 {
     raise(sig);
 }
 
-siginfo_t* SDL_EVDEV_kdb_cleanup_siginfo = NULL;
-void*      SDL_EVDEV_kdb_cleanup_ucontext = NULL;
+siginfo_t *SDL_EVDEV_kdb_cleanup_siginfo = NULL;
+void *SDL_EVDEV_kdb_cleanup_ucontext = NULL;
 
-static void kbd_cleanup_signal_action(int signum, siginfo_t* info, void* ucontext)
+static void kbd_cleanup_signal_action(int signum, siginfo_t *info, void *ucontext)
 {
-    struct sigaction* old_action_p = &(old_sigaction[signum]);
+    struct sigaction *old_action_p = &(old_sigaction[signum]);
     sigset_t sigset;
 
     /* Restore original signal handler before going any further. */
@@ -134,7 +134,7 @@ static void kbd_cleanup_signal_action(int signum, siginfo_t* info, void* ucontex
     SDL_EVDEV_kbd_reraise_signal(signum);
 }
 
-static void kbd_unregister_emerg_cleanup()
+static void kbd_unregister_emerg_cleanup(void)
 {
     int tabidx, signum;
 
@@ -146,19 +146,20 @@ static void kbd_unregister_emerg_cleanup()
     kbd_cleanup_sigactions_installed = 0;
 
     for (tabidx = 0; tabidx < sizeof(fatal_signals) / sizeof(fatal_signals[0]); ++tabidx) {
-        struct sigaction* old_action_p;
+        struct sigaction *old_action_p;
         struct sigaction cur_action;
         signum = fatal_signals[tabidx];
         old_action_p = &(old_sigaction[signum]);
 
         /* Examine current signal action */
-        if (sigaction(signum, NULL, &cur_action))
+        if (sigaction(signum, NULL, &cur_action)) {
             continue;
+        }
 
         /* Check if action installed and not modifed */
-        if (!(cur_action.sa_flags & SA_SIGINFO)
-                || cur_action.sa_sigaction != &kbd_cleanup_signal_action)
+        if (!(cur_action.sa_flags & SA_SIGINFO) || cur_action.sa_sigaction != &kbd_cleanup_signal_action) {
             continue;
+        }
 
         /* Restore original action */
         sigaction(signum, old_action_p, NULL);
@@ -174,11 +175,11 @@ static void kbd_cleanup_atexit(void)
     kbd_unregister_emerg_cleanup();
 }
 
-static void kbd_register_emerg_cleanup(SDL_EVDEV_keyboard_state * kbd)
+static void kbd_register_emerg_cleanup(SDL_EVDEV_keyboard_state *kbd)
 {
     int tabidx, signum;
 
-    if (kbd_cleanup_state != NULL) {
+    if (kbd_cleanup_state) {
         return;
     }
     kbd_cleanup_state = kbd;
@@ -198,20 +199,20 @@ static void kbd_register_emerg_cleanup(SDL_EVDEV_keyboard_state * kbd)
     kbd_cleanup_sigactions_installed = 1;
 
     for (tabidx = 0; tabidx < sizeof(fatal_signals) / sizeof(fatal_signals[0]); ++tabidx) {
-        struct sigaction* old_action_p;
+        struct sigaction *old_action_p;
         struct sigaction new_action;
-        signum = fatal_signals[tabidx];   
+        signum = fatal_signals[tabidx];
         old_action_p = &(old_sigaction[signum]);
-        if (sigaction(signum, NULL, old_action_p))
+        if (sigaction(signum, NULL, old_action_p)) {
             continue;
+        }
 
         /* Skip SIGHUP and SIGPIPE if handler is already installed
          * - assume the handler will do the cleanup
          */
-        if ((signum == SIGHUP || signum == SIGPIPE)
-                && (old_action_p->sa_handler != SIG_DFL 
-                    || (void (*)(int))old_action_p->sa_sigaction != SIG_DFL))
+        if ((signum == SIGHUP || signum == SIGPIPE) && (old_action_p->sa_handler != SIG_DFL || (void (*)(int))old_action_p->sa_sigaction != SIG_DFL)) {
             continue;
+        }
 
         new_action = *old_action_p;
         new_action.sa_flags |= SA_SIGINFO;
@@ -220,13 +221,12 @@ static void kbd_register_emerg_cleanup(SDL_EVDEV_keyboard_state * kbd)
     }
 }
 
-SDL_EVDEV_keyboard_state *
-SDL_EVDEV_kbd_init(void)
+SDL_EVDEV_keyboard_state *SDL_EVDEV_kbd_init(void)
 {
     SDL_EVDEV_keyboard_state *kbd;
     struct mouse_info mData;
     char flag_state;
-    char* devicePath;
+    char *devicePath;
 
     SDL_zero(mData);
     mData.operation = MOUSE_HIDE;
@@ -244,17 +244,16 @@ SDL_EVDEV_kbd_init(void)
 
     kbd->accents = SDL_calloc(sizeof(accentmap_t), 1);
     kbd->key_map = SDL_calloc(sizeof(keymap_t), 1);
-    kbd->kbInfo = SDL_calloc(sizeof(keyboard_info_t), 1);    
+    kbd->kbInfo = SDL_calloc(sizeof(keyboard_info_t), 1);
 
     ioctl(kbd->console_fd, KDGKBINFO, kbd->kbInfo);
     ioctl(kbd->console_fd, CONS_MOUSECTL, &mData);
-    
+
     if (ioctl(kbd->console_fd, KDGKBSTATE, &flag_state) == 0) {
         kbd->ledflagstate = flag_state;
     }
-    
-    if (ioctl(kbd->console_fd, GIO_DEADKEYMAP, kbd->accents) < 0)
-    {
+
+    if (ioctl(kbd->console_fd, GIO_DEADKEYMAP, kbd->accents) < 0) {
         SDL_free(kbd->accents);
         kbd->accents = &accentmap_default_us_acc;
     }
@@ -262,8 +261,7 @@ SDL_EVDEV_kbd_init(void)
     if (ioctl(kbd->console_fd, KDGKBMODE, &kbd->old_kbd_mode) == 0) {
         /* Set the keyboard in XLATE mode and load the keymaps */
         ioctl(kbd->console_fd, KDSKBMODE, (unsigned long)(K_XLATE));
-        if(!SDL_EVDEV_kbd_load_keymaps(kbd))
-        {
+        if (!SDL_EVDEV_kbd_load_keymaps(kbd)) {
             SDL_free(kbd->key_map);
             kbd->key_map = &keymap_default_us_acc;
         }
@@ -275,8 +273,7 @@ SDL_EVDEV_kbd_init(void)
             ioctl(kbd->console_fd, CONS_RELKBD, 1ul);
             SDL_asprintf(&devicePath, "/dev/kbd%d", kbd->kbInfo->kb_index);
             kbd->keyboard_fd = open(devicePath, O_WRONLY | O_CLOEXEC);
-            if (kbd->keyboard_fd == -1)
-            {
+            if (kbd->keyboard_fd == -1) {
                 // Give keyboard back.
                 ioctl(kbd->console_fd, CONS_SETKBD, (unsigned long)(kbd->kbInfo->kb_index));
                 kbd->keyboard_fd = kbd->console_fd;
@@ -289,15 +286,14 @@ SDL_EVDEV_kbd_init(void)
                 kbd_register_emerg_cleanup(kbd);
             }
             SDL_free(devicePath);
-        }
-        else kbd->keyboard_fd = kbd->console_fd;
+        } else
+            kbd->keyboard_fd = kbd->console_fd;
     }
 
     return kbd;
 }
 
-void
-SDL_EVDEV_kbd_quit(SDL_EVDEV_keyboard_state *kbd)
+void SDL_EVDEV_kbd_quit(SDL_EVDEV_keyboard_state *kbd)
 {
     struct mouse_info mData;
 
@@ -315,8 +311,7 @@ SDL_EVDEV_kbd_quit(SDL_EVDEV_keyboard_state *kbd)
         ioctl(kbd->keyboard_fd, KDSKBMODE, kbd->old_kbd_mode);
 
         close(kbd->keyboard_fd);
-        if (kbd->console_fd != kbd->keyboard_fd && kbd->console_fd >= 0)
-        {
+        if (kbd->console_fd != kbd->keyboard_fd && kbd->console_fd >= 0) {
             // Give back keyboard.
             ioctl(kbd->console_fd, CONS_SETKBD, (unsigned long)(kbd->kbInfo->kb_index));
         }
@@ -326,13 +321,25 @@ SDL_EVDEV_kbd_quit(SDL_EVDEV_keyboard_state *kbd)
     SDL_free(kbd);
 }
 
+void SDL_EVDEV_kbd_set_muted(SDL_EVDEV_keyboard_state *state, SDL_bool muted)
+{
+}
+
+void SDL_EVDEV_kbd_set_vt_switch_callbacks(SDL_EVDEV_keyboard_state *state, void (*release_callback)(void*), void *release_callback_data, void (*acquire_callback)(void*), void *acquire_callback_data)
+{
+}
+
+void SDL_EVDEV_kbd_update(SDL_EVDEV_keyboard_state *state)
+{
+}
+
 /*
  * Helper Functions.
  */
 static void put_queue(SDL_EVDEV_keyboard_state *kbd, uint c)
 {
     /* c is already part of a UTF-8 sequence and safe to add as a character */
-    if (kbd->text_len < (sizeof(kbd->text)-1)) {
+    if (kbd->text_len < (sizeof(kbd->text) - 1)) {
         kbd->text[kbd->text_len++] = (char)c;
     }
 }
@@ -347,10 +354,12 @@ static void put_utf8(SDL_EVDEV_keyboard_state *kbd, uint c)
         put_queue(kbd, 0xc0 | (c >> 6));
         put_queue(kbd, 0x80 | (c & 0x3f));
     } else if (c < 0x10000) {
-        if (c >= 0xD800 && c < 0xE000)
+        if (c >= 0xD800 && c < 0xE000) {
             return;
-        if (c == 0xFFFF)
+        }
+        if (c == 0xFFFF) {
             return;
+        }
         /* 1110**** 10****** 10****** */
         put_queue(kbd, 0xe0 | (c >> 12));
         put_queue(kbd, 0x80 | ((c >> 6) & 0x3f));
@@ -379,13 +388,14 @@ static unsigned int handle_diacr(SDL_EVDEV_keyboard_state *kbd, unsigned int ch)
     kbd->diacr = 0;
 
     for (i = 0; i < kbd->accents->n_accs; i++) {
-        if (kbd->accents->acc[i].accchar == d)
-        {
+        if (kbd->accents->acc[i].accchar == d) {
             for (j = 0; j < NUM_ACCENTCHARS; ++j) {
-                    if (kbd->accents->acc[i].map[j][0] == 0)        /* end of table */
-                            break;
-                    if (kbd->accents->acc[i].map[j][0] == ch)
-                            return kbd->accents->acc[i].map[j][1];
+                if (kbd->accents->acc[i].map[j][0] == 0) { /* end of table */
+                    break;
+                }
+                if (kbd->accents->acc[i].map[j][0] == ch) {
+                    return kbd->accents->acc[i].map[j][1];
+                }
             }
         }
     }
@@ -416,11 +426,13 @@ static void chg_vc_kbd_led(SDL_EVDEV_keyboard_state *kbd, int flag)
 
 static void k_self(SDL_EVDEV_keyboard_state *kbd, unsigned int value, char up_flag)
 {
-    if (up_flag)
-        return;        /* no action, if this is a key release */
+    if (up_flag) {
+        return; /* no action, if this is a key release */
+    }
 
-    if (kbd->diacr)
+    if (kbd->diacr) {
         value = handle_diacr(kbd, value);
+    }
 
     if (kbd->dead_key_next) {
         kbd->dead_key_next = SDL_FALSE;
@@ -450,8 +462,9 @@ static void k_shift(SDL_EVDEV_keyboard_state *kbd, unsigned char value, char up_
          * handle the case that two shift or control
          * keys are depressed simultaneously
          */
-        if (kbd->shift_down[value])
+        if (kbd->shift_down[value]) {
             kbd->shift_down[value]--;
+        }
     } else
         kbd->shift_down[value]++;
 
@@ -467,20 +480,19 @@ static void k_shift(SDL_EVDEV_keyboard_state *kbd, unsigned char value, char up_
     }
 }
 
-void
-SDL_EVDEV_kbd_keycode(SDL_EVDEV_keyboard_state *kbd, unsigned int keycode, int down)
+void SDL_EVDEV_kbd_keycode(SDL_EVDEV_keyboard_state *kbd, unsigned int keycode, int down)
 {
     keymap_t key_map;
     struct keyent_t keysym;
     unsigned int final_key_state;
     unsigned int map_from_key_sym;
 
-    key_map = *kbd->key_map;
-
     if (!kbd) {
         return;
     }
 
+    key_map = *kbd->key_map;
+
     kbd->rep = (down == 2);
 
     if (keycode < NUM_KEYS) {
@@ -488,10 +500,10 @@ SDL_EVDEV_kbd_keycode(SDL_EVDEV_keyboard_state *kbd, unsigned int keycode, int d
             /* These constitute unprintable language-related keys, so ignore them. */
             return;
         }
-        if (keycode > 95)
+        if (keycode > 95) {
             keycode -= 7;
-        if (vc_kbd_led(kbd, ALKED) || (kbd->shift_state & 0x8))
-        {
+        }
+        if (vc_kbd_led(kbd, ALKED) || (kbd->shift_state & 0x8)) {
             keycode += ALTGR_OFFSET;
         }
         keysym = key_map.key[keycode];
@@ -500,18 +512,21 @@ SDL_EVDEV_kbd_keycode(SDL_EVDEV_keyboard_state *kbd, unsigned int keycode, int d
     }
 
     final_key_state = kbd->shift_state & 0x7;
-    if ((keysym.flgs & FLAG_LOCK_C) && vc_kbd_led(kbd, LED_CAP))
+    if ((keysym.flgs & FLAG_LOCK_C) && vc_kbd_led(kbd, LED_CAP)) {
         final_key_state ^= 0x1;
-    if ((keysym.flgs & FLAG_LOCK_N) && vc_kbd_led(kbd, LED_NUM))
+    }
+    if ((keysym.flgs & FLAG_LOCK_N) && vc_kbd_led(kbd, LED_NUM)) {
         final_key_state ^= 0x1;
+    }
 
     map_from_key_sym = keysym.map[final_key_state];
     if ((keysym.spcl & (0x80 >> final_key_state)) || (map_from_key_sym & SPCLKEY)) {
         /* Special function.*/
         if (map_from_key_sym == 0)
             return; /* Nothing to do. */
-        if (map_from_key_sym & SPCLKEY)
+        if (map_from_key_sym & SPCLKEY) {
             map_from_key_sym &= ~SPCLKEY;
+        }
         if (map_from_key_sym >= F_ACC && map_from_key_sym <= L_ACC) {
             /* Accent function.*/
             unsigned int accent_index = map_from_key_sym - F_ACC;
@@ -519,42 +534,56 @@ SDL_EVDEV_kbd_keycode(SDL_EVDEV_keyboard_state *kbd, unsigned int keycode, int d
                 k_deadunicode(kbd, kbd->accents->acc[accent_index].accchar, !down);
             }
         } else {
-            switch(map_from_key_sym) {
+            switch (map_from_key_sym) {
             case ASH: /* alt/meta shift */
                 k_shift(kbd, 3, down == 0);
                 break;
             case LSHA: /* left shift + alt lock */
             case RSHA: /* right shift + alt lock */
-                if (down == 0) chg_vc_kbd_led(kbd, ALKED);
+                if (down == 0) {
+                    chg_vc_kbd_led(kbd, ALKED);
+                }
             case LSH: /* left shift */
             case RSH: /* right shift */
                 k_shift(kbd, 0, down == 0);
                 break;
             case LCTRA: /* left ctrl + alt lock */
             case RCTRA: /* right ctrl + alt lock */
-                if (down == 0) chg_vc_kbd_led(kbd, ALKED);
+                if (down == 0) {
+                    chg_vc_kbd_led(kbd, ALKED);
+                }
             case LCTR: /* left ctrl */
             case RCTR: /* right ctrl */
                 k_shift(kbd, 1, down == 0);
                 break;
             case LALTA: /* left alt + alt lock */
             case RALTA: /* right alt + alt lock */
-                if (down == 0) chg_vc_kbd_led(kbd, ALKED);
+                if (down == 0) {
+                    chg_vc_kbd_led(kbd, ALKED);
+                }
             case LALT: /* left alt */
             case RALT: /* right alt */
                 k_shift(kbd, 2, down == 0);
                 break;
             case ALK: /* alt lock */
-                if (down == 1) chg_vc_kbd_led(kbd, ALKED);
+                if (down == 1) {
+                    chg_vc_kbd_led(kbd, ALKED);
+                }
                 break;
             case CLK: /* caps lock*/
-                if (down == 1) chg_vc_kbd_led(kbd, CLKED);
+                if (down == 1) {
+                    chg_vc_kbd_led(kbd, CLKED);
+                }
                 break;
             case NLK: /* num lock */
-                if (down == 1) chg_vc_kbd_led(kbd, NLKED);
+                if (down == 1) {
+                    chg_vc_kbd_led(kbd, NLKED);
+                }
                 break;
             case SLK: /* scroll lock */
-                if (down == 1) chg_vc_kbd_led(kbd, SLKED);
+                if (down == 1) {
+                    chg_vc_kbd_led(kbd, SLKED);
+                }
                 break;
             default:
                 return;
