@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_HAPTIC_DINPUT || SDL_HAPTIC_XINPUT
+#if defined(SDL_HAPTIC_DINPUT) || defined(SDL_HAPTIC_XINPUT)
 
 #include "SDL_thread.h"
 #include "SDL_mutex.h"
@@ -49,14 +49,12 @@ SDL_hapticlist_item *SDL_hapticlist = NULL;
 static SDL_hapticlist_item *SDL_hapticlist_tail = NULL;
 static int numhaptics = 0;
 
-
 /*
  * Initializes the haptic subsystem.
  */
-int
-SDL_SYS_HapticInit(void)
+int SDL_SYS_HapticInit(void)
 {
-    JoyStick_DeviceData* device;
+    JoyStick_DeviceData *device;
 
     if (SDL_DINPUT_HapticInit() < 0) {
         return -1;
@@ -81,10 +79,9 @@ SDL_SYS_HapticInit(void)
     return numhaptics;
 }
 
-int
-SDL_SYS_AddHapticDevice(SDL_hapticlist_item *item)
+int SDL_SYS_AddHapticDevice(SDL_hapticlist_item *item)
 {
-    if (SDL_hapticlist_tail == NULL) {
+    if (!SDL_hapticlist_tail) {
         SDL_hapticlist = SDL_hapticlist_tail = item;
     } else {
         SDL_hapticlist_tail->next = item;
@@ -97,11 +94,10 @@ SDL_SYS_AddHapticDevice(SDL_hapticlist_item *item)
     return numhaptics;
 }
 
-int
-SDL_SYS_RemoveHapticDevice(SDL_hapticlist_item *prev, SDL_hapticlist_item *item)
+int SDL_SYS_RemoveHapticDevice(SDL_hapticlist_item *prev, SDL_hapticlist_item *item)
 {
     const int retval = item->haptic ? item->haptic->index : -1;
-    if (prev != NULL) {
+    if (prev) {
         prev->next = item->next;
     } else {
         SDL_assert(SDL_hapticlist == item);
@@ -116,14 +112,12 @@ SDL_SYS_RemoveHapticDevice(SDL_hapticlist_item *prev, SDL_hapticlist_item *item)
     return retval;
 }
 
-int
-SDL_SYS_NumHaptics(void)
+int SDL_SYS_NumHaptics(void)
 {
     return numhaptics;
 }
 
-static SDL_hapticlist_item *
-HapticByDevIndex(int device_index)
+static SDL_hapticlist_item *HapticByDevIndex(int device_index)
 {
     SDL_hapticlist_item *item = SDL_hapticlist;
 
@@ -142,8 +136,7 @@ HapticByDevIndex(int device_index)
 /*
  * Return the name of a haptic device, does not need to be opened.
  */
-const char *
-SDL_SYS_HapticName(int index)
+const char *SDL_SYS_HapticName(int index)
 {
     SDL_hapticlist_item *item = HapticByDevIndex(index);
     return item->name;
@@ -152,8 +145,7 @@ SDL_SYS_HapticName(int index)
 /*
  * Opens a haptic device for usage.
  */
-int
-SDL_SYS_HapticOpen(SDL_Haptic * haptic)
+int SDL_SYS_HapticOpen(SDL_Haptic *haptic)
 {
     SDL_hapticlist_item *item = HapticByDevIndex(haptic->index);
     if (item->bXInputHaptic) {
@@ -163,19 +155,17 @@ SDL_SYS_HapticOpen(SDL_Haptic * haptic)
     }
 }
 
-
 /*
  * Opens a haptic device from first mouse it finds for usage.
  */
-int
-SDL_SYS_HapticMouse(void)
+int SDL_SYS_HapticMouse(void)
 {
-#if SDL_HAPTIC_DINPUT
+#ifdef SDL_HAPTIC_DINPUT
     SDL_hapticlist_item *item;
     int index = 0;
 
     /* Grab the first mouse haptic device we find. */
-    for (item = SDL_hapticlist; item != NULL; item = item->next) {
+    for (item = SDL_hapticlist; item; item = item->next) {
         if (item->capabilities.dwDevType == DI8DEVCLASS_POINTER) {
             return index;
         }
@@ -185,22 +175,20 @@ SDL_SYS_HapticMouse(void)
     return -1;
 }
 
-
 /*
  * Checks to see if a joystick has haptic features.
  */
-int
-SDL_SYS_JoystickIsHaptic(SDL_Joystick * joystick)
+int SDL_SYS_JoystickIsHaptic(SDL_Joystick *joystick)
 {
     if (joystick->driver != &SDL_WINDOWS_JoystickDriver) {
         return 0;
     }
-#if SDL_HAPTIC_XINPUT
+#ifdef SDL_HAPTIC_XINPUT
     if (joystick->hwdata->bXInputHaptic) {
         return 1;
     }
 #endif
-#if SDL_HAPTIC_DINPUT
+#ifdef SDL_HAPTIC_DINPUT
     if (joystick->hwdata->Capabilities.dwFlags & DIDC_FORCEFEEDBACK) {
         return 1;
     }
@@ -211,14 +199,13 @@ SDL_SYS_JoystickIsHaptic(SDL_Joystick * joystick)
 /*
  * Checks to see if the haptic device and joystick are in reality the same.
  */
-int
-SDL_SYS_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_SYS_JoystickSameHaptic(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     if (joystick->driver != &SDL_WINDOWS_JoystickDriver) {
         return 0;
     }
     if (joystick->hwdata->bXInputHaptic != haptic->hwdata->bXInputHaptic) {
-        return 0;  /* one is XInput, one is not; not the same device. */
+        return 0; /* one is XInput, one is not; not the same device. */
     } else if (joystick->hwdata->bXInputHaptic) {
         return SDL_XINPUT_JoystickSameHaptic(haptic, joystick);
     } else {
@@ -229,8 +216,7 @@ SDL_SYS_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
 /*
  * Opens a SDL_Haptic from a SDL_Joystick.
  */
-int
-SDL_SYS_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_SYS_HapticOpenFromJoystick(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     SDL_assert(joystick->driver == &SDL_WINDOWS_JoystickDriver);
 
@@ -244,8 +230,7 @@ SDL_SYS_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
 /*
  * Closes the haptic device.
  */
-void
-SDL_SYS_HapticClose(SDL_Haptic * haptic)
+void SDL_SYS_HapticClose(SDL_Haptic *haptic)
 {
     if (haptic->hwdata) {
 
@@ -270,8 +255,7 @@ SDL_SYS_HapticClose(SDL_Haptic * haptic)
 /*
  * Clean up after system specific haptic stuff
  */
-void
-SDL_SYS_HapticQuit(void)
+void SDL_SYS_HapticQuit(void)
 {
     SDL_hapticlist_item *item;
     SDL_hapticlist_item *next = NULL;
@@ -307,16 +291,15 @@ SDL_SYS_HapticQuit(void)
 /*
  * Creates a new haptic effect.
  */
-int
-SDL_SYS_HapticNewEffect(SDL_Haptic * haptic, struct haptic_effect *effect,
-                        SDL_HapticEffect * base)
+int SDL_SYS_HapticNewEffect(SDL_Haptic *haptic, struct haptic_effect *effect,
+                            SDL_HapticEffect *base)
 {
     int result;
 
     /* Alloc the effect. */
     effect->hweffect = (struct haptic_hweffect *)
         SDL_malloc(sizeof(struct haptic_hweffect));
-    if (effect->hweffect == NULL) {
+    if (!effect->hweffect) {
         SDL_OutOfMemory();
         return -1;
     }
@@ -337,10 +320,9 @@ SDL_SYS_HapticNewEffect(SDL_Haptic * haptic, struct haptic_effect *effect,
 /*
  * Updates an effect.
  */
-int
-SDL_SYS_HapticUpdateEffect(SDL_Haptic * haptic,
-                           struct haptic_effect *effect,
-                           SDL_HapticEffect * data)
+int SDL_SYS_HapticUpdateEffect(SDL_Haptic *haptic,
+                               struct haptic_effect *effect,
+                               SDL_HapticEffect *data)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticUpdateEffect(haptic, effect, data);
@@ -352,9 +334,8 @@ SDL_SYS_HapticUpdateEffect(SDL_Haptic * haptic,
 /*
  * Runs an effect.
  */
-int
-SDL_SYS_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect,
-                        Uint32 iterations)
+int SDL_SYS_HapticRunEffect(SDL_Haptic *haptic, struct haptic_effect *effect,
+                            Uint32 iterations)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticRunEffect(haptic, effect, iterations);
@@ -366,8 +347,7 @@ SDL_SYS_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect,
 /*
  * Stops an effect.
  */
-int
-SDL_SYS_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_SYS_HapticStopEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticStopEffect(haptic, effect);
@@ -379,8 +359,7 @@ SDL_SYS_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
 /*
  * Frees the effect.
  */
-void
-SDL_SYS_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+void SDL_SYS_HapticDestroyEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     if (haptic->hwdata->bXInputHaptic) {
         SDL_XINPUT_HapticDestroyEffect(haptic, effect);
@@ -394,9 +373,8 @@ SDL_SYS_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
 /*
  * Gets the status of a haptic effect.
  */
-int
-SDL_SYS_HapticGetEffectStatus(SDL_Haptic * haptic,
-                              struct haptic_effect *effect)
+int SDL_SYS_HapticGetEffectStatus(SDL_Haptic *haptic,
+                                  struct haptic_effect *effect)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticGetEffectStatus(haptic, effect);
@@ -408,8 +386,7 @@ SDL_SYS_HapticGetEffectStatus(SDL_Haptic * haptic,
 /*
  * Sets the gain.
  */
-int
-SDL_SYS_HapticSetGain(SDL_Haptic * haptic, int gain)
+int SDL_SYS_HapticSetGain(SDL_Haptic *haptic, int gain)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticSetGain(haptic, gain);
@@ -421,8 +398,7 @@ SDL_SYS_HapticSetGain(SDL_Haptic * haptic, int gain)
 /*
  * Sets the autocentering.
  */
-int
-SDL_SYS_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
+int SDL_SYS_HapticSetAutocenter(SDL_Haptic *haptic, int autocenter)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticSetAutocenter(haptic, autocenter);
@@ -434,8 +410,7 @@ SDL_SYS_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
 /*
  * Pauses the device.
  */
-int
-SDL_SYS_HapticPause(SDL_Haptic * haptic)
+int SDL_SYS_HapticPause(SDL_Haptic *haptic)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticPause(haptic);
@@ -447,8 +422,7 @@ SDL_SYS_HapticPause(SDL_Haptic * haptic)
 /*
  * Pauses the device.
  */
-int
-SDL_SYS_HapticUnpause(SDL_Haptic * haptic)
+int SDL_SYS_HapticUnpause(SDL_Haptic *haptic)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticUnpause(haptic);
@@ -460,8 +434,7 @@ SDL_SYS_HapticUnpause(SDL_Haptic * haptic)
 /*
  * Stops all the playing effects on the device.
  */
-int
-SDL_SYS_HapticStopAll(SDL_Haptic * haptic)
+int SDL_SYS_HapticStopAll(SDL_Haptic *haptic)
 {
     if (haptic->hwdata->bXInputHaptic) {
         return SDL_XINPUT_HapticStopAll(haptic);
