@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -22,23 +22,28 @@
 
 /* System independent thread management routines for SDL */
 
-#include "SDL_assert.h"
 #include "SDL_thread.h"
 #include "SDL_thread_c.h"
 #include "SDL_systhread.h"
 #include "SDL_hints.h"
 #include "../SDL_error_c.h"
 
+/* The storage is local to the thread, but the IDs are global for the process */
 
-SDL_TLSID
-SDL_TLSCreate()
+static SDL_atomic_t SDL_tls_allocated;
+
+void SDL_InitTLSData(void)
 {
-    static SDL_atomic_t SDL_tls_id;
-    return SDL_AtomicIncRef(&SDL_tls_id)+1;
+    SDL_SYS_InitTLSData();
 }
 
-void *
-SDL_TLSGet(SDL_TLSID id)
+SDL_TLSID SDL_TLSCreate(void)
+{
+    static SDL_atomic_t SDL_tls_id;
+    return SDL_AtomicIncRef(&SDL_tls_id) + 1;
+}
+
+void *SDL_TLSGet(SDL_TLSID id)
 {
     SDL_TLSData *storage;
 
@@ -46,11 +51,10 @@ SDL_TLSGet(SDL_TLSID id)
     if (!storage || id == 0 || id > storage->limit) {
         return NULL;
     }
-    return storage->array[id-1].data;
+    return storage->array[id - 1].data;
 }
 
-int
-SDL_TLSSet(SDL_TLSID id, const void *value, void (SDLCALL *destructor)(void *))
+int SDL_TLSSet(SDL_TLSID id, const void *value, SDL_TLSDestructorCallback destructor)
 {
     SDL_TLSData *storage;
 
@@ -58,13 +62,20 @@ SDL_TLSSet(SDL_TLSID id, const void *value, void (SDLCALL *destructor)(void *))
         return SDL_InvalidParamError("id");
     }
 
+    /* Make sure TLS is initialized.
+     * There's a race condition here if you are calling this from non-SDL threads
+     * and haven't called SDL_Init() on your main thread, but such is life.
+     */
+    SDL_InitTLSData();
+
+    /* Get the storage for the current thread */
     storage = SDL_SYS_GetTLSData();
     if (!storage || (id > storage->limit)) {
         unsigned int i, oldlimit, newlimit;
 
         oldlimit = storage ? storage->limit : 0;
         newlimit = (id + TLS_ALLOC_CHUNKSIZE);
-        storage = (SDL_TLSData *)SDL_realloc(storage, sizeof(*storage)+(newlimit-1)*sizeof(storage->array[0]));
+        storage = (SDL_TLSData *)SDL_realloc(storage, sizeof(*storage) + (newlimit - 1) * sizeof(storage->array[0]));
         if (!storage) {
             return SDL_OutOfMemory();
         }
@@ -74,20 +85,22 @@ SDL_TLSSet(SDL_TLSID id, const void *value, void (SDLCALL *destructor)(void *))
             storage->array[i].destructor = NULL;
         }
         if (SDL_SYS_SetTLSData(storage) != 0) {
+            SDL_free(storage);
             return -1;
         }
+        SDL_AtomicIncRef(&SDL_tls_allocated);
     }
 
-    storage->array[id-1].data = SDL_const_cast(void*, value);
-    storage->array[id-1].destructor = destructor;
+    storage->array[id - 1].data = SDL_const_cast(void *, value);
+    storage->array[id - 1].destructor = destructor;
     return 0;
 }
 
-static void
-SDL_TLSCleanup()
+void SDL_TLSCleanup(void)
 {
     SDL_TLSData *storage;
 
+    /* Cleanup the storage for the current thread */
     storage = SDL_SYS_GetTLSData();
     if (storage) {
         unsigned int i;
@@ -98,9 +111,20 @@ SDL_TLSCleanup()
         }
         SDL_SYS_SetTLSData(NULL);
         SDL_free(storage);
+        (void)SDL_AtomicDecRef(&SDL_tls_allocated);
     }
 }
 
+void SDL_QuitTLSData(void)
+{
+    SDL_TLSCleanup();
+
+    if (SDL_AtomicGet(&SDL_tls_allocated) == 0) {
+        SDL_SYS_QuitTLSData();
+    } else {
+        /* Some thread hasn't called SDL_CleanupTLS() */
+    }
+}
 
 /* This is a generic implementation of thread-local storage which doesn't
    require additional OS support.
@@ -110,7 +134,8 @@ SDL_TLSCleanup()
    storage this implementation should be improved to be production quality.
 */
 
-typedef struct SDL_TLSEntry {
+typedef struct SDL_TLSEntry
+{
     SDL_threadID thread;
     SDL_TLSData *storage;
     struct SDL_TLSEntry *next;
@@ -119,32 +144,19 @@ typedef struct SDL_TLSEntry {
 static SDL_mutex *SDL_generic_TLS_mutex;
 static SDL_TLSEntry *SDL_generic_TLS;
 
+void SDL_Generic_InitTLSData(void)
+{
+    if (!SDL_generic_TLS_mutex) {
+        SDL_generic_TLS_mutex = SDL_CreateMutex();
+    }
+}
 
-SDL_TLSData *
-SDL_Generic_GetTLSData(void)
+SDL_TLSData *SDL_Generic_GetTLSData(void)
 {
     SDL_threadID thread = SDL_ThreadID();
     SDL_TLSEntry *entry;
     SDL_TLSData *storage = NULL;
 
-#if !SDL_THREADS_DISABLED
-    if (!SDL_generic_TLS_mutex) {
-        static SDL_SpinLock tls_lock;
-        SDL_AtomicLock(&tls_lock);
-        if (!SDL_generic_TLS_mutex) {
-            SDL_mutex *mutex = SDL_CreateMutex();
-            SDL_MemoryBarrierRelease();
-            SDL_generic_TLS_mutex = mutex;
-            if (!SDL_generic_TLS_mutex) {
-                SDL_AtomicUnlock(&tls_lock);
-                return NULL;
-            }
-        }
-        SDL_AtomicUnlock(&tls_lock);
-    }
-#endif /* SDL_THREADS_DISABLED */
-
-    SDL_MemoryBarrierAcquire();
     SDL_LockMutex(SDL_generic_TLS_mutex);
     for (entry = SDL_generic_TLS; entry; entry = entry->next) {
         if (entry->thread == thread) {
@@ -152,26 +164,23 @@ SDL_Generic_GetTLSData(void)
             break;
         }
     }
-#if !SDL_THREADS_DISABLED
     SDL_UnlockMutex(SDL_generic_TLS_mutex);
-#endif
 
     return storage;
 }
 
-int
-SDL_Generic_SetTLSData(SDL_TLSData *storage)
+int SDL_Generic_SetTLSData(SDL_TLSData *data)
 {
     SDL_threadID thread = SDL_ThreadID();
     SDL_TLSEntry *prev, *entry;
+    int retval = 0;
 
-    /* SDL_Generic_GetTLSData() is always called first, so we can assume SDL_generic_TLS_mutex */
     SDL_LockMutex(SDL_generic_TLS_mutex);
     prev = NULL;
     for (entry = SDL_generic_TLS; entry; entry = entry->next) {
         if (entry->thread == thread) {
-            if (storage) {
-                entry->storage = storage;
+            if (data) {
+                entry->storage = data;
             } else {
                 if (prev) {
                     prev->next = entry->next;
@@ -184,31 +193,77 @@ SDL_Generic_SetTLSData(SDL_TLSData *storage)
         }
         prev = entry;
     }
-    if (!entry) {
+    if (!entry && data) {
         entry = (SDL_TLSEntry *)SDL_malloc(sizeof(*entry));
         if (entry) {
             entry->thread = thread;
-            entry->storage = storage;
+            entry->storage = data;
             entry->next = SDL_generic_TLS;
             SDL_generic_TLS = entry;
+        } else {
+            retval = SDL_OutOfMemory();
         }
     }
     SDL_UnlockMutex(SDL_generic_TLS_mutex);
 
-    if (!entry) {
-        return SDL_OutOfMemory();
-    }
-    return 0;
+    return retval;
 }
 
-/* Routine to get the thread-specific error variable */
-SDL_error *
-SDL_GetErrBuf(void)
+void SDL_Generic_QuitTLSData(void)
 {
+    SDL_TLSEntry *entry;
+
+    /* This should have been cleaned up by the time we get here */
+    SDL_assert(!SDL_generic_TLS);
+    if (SDL_generic_TLS) {
+        SDL_LockMutex(SDL_generic_TLS_mutex);
+        for (entry = SDL_generic_TLS; entry; ) {
+            SDL_TLSEntry *next = entry->next;
+            SDL_free(entry->storage);
+            SDL_free(entry);
+            entry = next;
+        }
+        SDL_generic_TLS = NULL;
+        SDL_UnlockMutex(SDL_generic_TLS_mutex);
+    }
+
+    if (SDL_generic_TLS_mutex) {
+        SDL_DestroyMutex(SDL_generic_TLS_mutex);
+        SDL_generic_TLS_mutex = NULL;
+    }
+}
+
+/* Non-thread-safe global error variable */
+static SDL_error *SDL_GetStaticErrBuf(void)
+{
+    static SDL_error SDL_global_error;
+    static char SDL_global_error_str[128];
+    SDL_global_error.str = SDL_global_error_str;
+    SDL_global_error.len = sizeof(SDL_global_error_str);
+    return &SDL_global_error;
+}
+
+#ifndef SDL_THREADS_DISABLED
+static void SDLCALL SDL_FreeErrBuf(void *data)
+{
+    SDL_error *errbuf = (SDL_error *)data;
+
+    if (errbuf->str) {
+        errbuf->free_func(errbuf->str);
+    }
+    errbuf->free_func(errbuf);
+}
+#endif
+
+/* Routine to get the thread-specific error variable */
+SDL_error *SDL_GetErrBuf(void)
+{
+#ifdef SDL_THREADS_DISABLED
+    return SDL_GetStaticErrBuf();
+#else
     static SDL_SpinLock tls_lock;
     static SDL_bool tls_being_created;
     static SDL_TLSID tls_errbuf;
-    static SDL_error SDL_global_errbuf;
     const SDL_error *ALLOCATION_IN_PROGRESS = (SDL_error *)-1;
     SDL_error *errbuf;
 
@@ -229,45 +284,43 @@ SDL_GetErrBuf(void)
         SDL_AtomicUnlock(&tls_lock);
     }
     if (!tls_errbuf) {
-        return &SDL_global_errbuf;
+        return SDL_GetStaticErrBuf();
     }
 
     SDL_MemoryBarrierAcquire();
     errbuf = (SDL_error *)SDL_TLSGet(tls_errbuf);
     if (errbuf == ALLOCATION_IN_PROGRESS) {
-        return &SDL_global_errbuf;
+        return SDL_GetStaticErrBuf();
     }
     if (!errbuf) {
+        /* Get the original memory functions for this allocation because the lifetime
+         * of the error buffer may span calls to SDL_SetMemoryFunctions() by the app
+         */
+        SDL_realloc_func realloc_func;
+        SDL_free_func free_func;
+        SDL_GetOriginalMemoryFunctions(NULL, NULL, &realloc_func, &free_func);
+
         /* Mark that we're in the middle of allocating our buffer */
         SDL_TLSSet(tls_errbuf, ALLOCATION_IN_PROGRESS, NULL);
-        errbuf = (SDL_error *)SDL_malloc(sizeof(*errbuf));
+        errbuf = (SDL_error *)realloc_func(NULL, sizeof(*errbuf));
         if (!errbuf) {
             SDL_TLSSet(tls_errbuf, NULL, NULL);
-            return &SDL_global_errbuf;
+            return SDL_GetStaticErrBuf();
         }
         SDL_zerop(errbuf);
-        SDL_TLSSet(tls_errbuf, errbuf, SDL_free);
+        errbuf->realloc_func = realloc_func;
+        errbuf->free_func = free_func;
+        SDL_TLSSet(tls_errbuf, errbuf, SDL_FreeErrBuf);
     }
     return errbuf;
+#endif /* SDL_THREADS_DISABLED */
 }
 
-
-/* Arguments and callback to setup and run the user thread function */
-typedef struct
+void SDL_RunThread(SDL_Thread *thread)
 {
-    int (SDLCALL * func) (void *);
-    void *data;
-    SDL_Thread *info;
-    SDL_sem *wait;
-} thread_args;
+    void *userdata = thread->userdata;
+    int(SDLCALL * userfunc)(void *) = thread->userfunc;
 
-void
-SDL_RunThread(void *data)
-{
-    thread_args *args = (thread_args *) data;
-    int (SDLCALL * userfunc) (void *) = args->func;
-    void *userdata = args->data;
-    SDL_Thread *thread = args->info;
     int *statusloc = &thread->status;
 
     /* Perform any system-dependent setup - this function may not fail */
@@ -276,9 +329,6 @@ SDL_RunThread(void *data)
     /* Get the thread id */
     thread->threadid = SDL_ThreadID();
 
-    /* Wake up the parent thread */
-    SDL_SemPost(args->wait);
-
     /* Run the function */
     *statusloc = userfunc(userdata);
 
@@ -299,105 +349,75 @@ SDL_RunThread(void *data)
 
 #ifdef SDL_CreateThread
 #undef SDL_CreateThread
+#undef SDL_CreateThreadWithStackSize
 #endif
 #if SDL_DYNAMIC_API
-#define SDL_CreateThread SDL_CreateThread_REAL
+#define SDL_CreateThread              SDL_CreateThread_REAL
+#define SDL_CreateThreadWithStackSize SDL_CreateThreadWithStackSize_REAL
 #endif
 
 #ifdef SDL_PASSED_BEGINTHREAD_ENDTHREAD
-static SDL_Thread *
-SDL_CreateThreadWithStackSize(int (SDLCALL * fn) (void *),
-                 const char *name, const size_t stacksize, void *data,
-                 pfnSDL_CurrentBeginThread pfnBeginThread,
-                 pfnSDL_CurrentEndThread pfnEndThread)
+SDL_Thread *SDL_CreateThreadWithStackSize(int(SDLCALL *fn)(void *),
+                              const char *name, const size_t stacksize, void *data,
+                              pfnSDL_CurrentBeginThread pfnBeginThread,
+                              pfnSDL_CurrentEndThread pfnEndThread)
 #else
-static SDL_Thread *
-SDL_CreateThreadWithStackSize(int (SDLCALL * fn) (void *),
-                const char *name, const size_t stacksize, void *data)
+SDL_Thread *SDL_CreateThreadWithStackSize(int(SDLCALL *fn)(void *),
+                              const char *name, const size_t stacksize, void *data)
 #endif
 {
     SDL_Thread *thread;
-    thread_args *args;
     int ret;
 
+    SDL_InitMainThread();
+
     /* Allocate memory for the thread info structure */
-    thread = (SDL_Thread *) SDL_malloc(sizeof(*thread));
-    if (thread == NULL) {
+    thread = (SDL_Thread *)SDL_calloc(1, sizeof(*thread));
+    if (!thread) {
         SDL_OutOfMemory();
-        return (NULL);
+        return NULL;
     }
-    SDL_zerop(thread);
     thread->status = -1;
     SDL_AtomicSet(&thread->state, SDL_THREAD_STATE_ALIVE);
 
     /* Set up the arguments for the thread */
-    if (name != NULL) {
+    if (name) {
         thread->name = SDL_strdup(name);
-        if (thread->name == NULL) {
+        if (!thread->name) {
             SDL_OutOfMemory();
             SDL_free(thread);
-            return (NULL);
+            return NULL;
         }
     }
 
-    /* Set up the arguments for the thread */
-    args = (thread_args *) SDL_malloc(sizeof(*args));
-    if (args == NULL) {
-        SDL_OutOfMemory();
-        if (thread->name) {
-            SDL_free(thread->name);
-        }
-        SDL_free(thread);
-        return (NULL);
-    }
-    args->func = fn;
-    args->data = data;
-    args->info = thread;
-    args->wait = SDL_CreateSemaphore(0);
-    if (args->wait == NULL) {
-        if (thread->name) {
-            SDL_free(thread->name);
-        }
-        SDL_free(thread);
-        SDL_free(args);
-        return (NULL);
-    }
-
+    thread->userfunc = fn;
+    thread->userdata = data;
     thread->stacksize = stacksize;
 
     /* Create the thread and go! */
 #ifdef SDL_PASSED_BEGINTHREAD_ENDTHREAD
-    ret = SDL_SYS_CreateThread(thread, args, pfnBeginThread, pfnEndThread);
+    ret = SDL_SYS_CreateThread(thread, pfnBeginThread, pfnEndThread);
 #else
-    ret = SDL_SYS_CreateThread(thread, args);
+    ret = SDL_SYS_CreateThread(thread);
 #endif
-    if (ret >= 0) {
-        /* Wait for the thread function to use arguments */
-        SDL_SemWait(args->wait);
-    } else {
+    if (ret < 0) {
         /* Oops, failed.  Gotta free everything */
-        if (thread->name) {
-            SDL_free(thread->name);
-        }
+        SDL_free(thread->name);
         SDL_free(thread);
         thread = NULL;
     }
-    SDL_DestroySemaphore(args->wait);
-    SDL_free(args);
 
     /* Everything is running now */
-    return (thread);
+    return thread;
 }
 
 #ifdef SDL_PASSED_BEGINTHREAD_ENDTHREAD
-DECLSPEC SDL_Thread *SDLCALL
-SDL_CreateThread(int (SDLCALL * fn) (void *),
+DECLSPEC SDL_Thread *SDLCALL SDL_CreateThread(int(SDLCALL *fn)(void *),
                  const char *name, void *data,
                  pfnSDL_CurrentBeginThread pfnBeginThread,
                  pfnSDL_CurrentEndThread pfnEndThread)
 #else
-DECLSPEC SDL_Thread *SDLCALL
-SDL_CreateThread(int (SDLCALL * fn) (void *),
+DECLSPEC SDL_Thread *SDLCALL SDL_CreateThread(int(SDLCALL *fn)(void *),
                  const char *name, void *data)
 #endif
 {
@@ -406,12 +426,12 @@ SDL_CreateThread(int (SDLCALL * fn) (void *),
     size_t stacksize = 0;
 
     /* If the SDL_HINT_THREAD_STACK_SIZE exists, use it */
-    if (stackhint != NULL) {
+    if (stackhint) {
         char *endp = NULL;
         const Sint64 hintval = SDL_strtoll(stackhint, &endp, 10);
-        if ((*stackhint != '\0') && (*endp == '\0')) {  /* a valid number? */
-            if (hintval > 0) {  /* reject bogus values. */
-                stacksize = (size_t) hintval;
+        if ((*stackhint != '\0') && (*endp == '\0')) { /* a valid number? */
+            if (hintval > 0) {                         /* reject bogus values. */
+                stacksize = (size_t)hintval;
             }
         }
     }
@@ -423,9 +443,9 @@ SDL_CreateThread(int (SDLCALL * fn) (void *),
 #endif
 }
 
-SDL_Thread *
-SDL_CreateThreadInternal(int (SDLCALL * fn) (void *), const char *name,
-                         const size_t stacksize, void *data) {
+SDL_Thread *SDL_CreateThreadInternal(int(SDLCALL *fn)(void *), const char *name,
+                         const size_t stacksize, void *data)
+{
 #ifdef SDL_PASSED_BEGINTHREAD_ENDTHREAD
     return SDL_CreateThreadWithStackSize(fn, name, stacksize, data, NULL, NULL);
 #else
@@ -433,8 +453,7 @@ SDL_CreateThreadInternal(int (SDLCALL * fn) (void *), const char *name,
 #endif
 }
 
-SDL_threadID
-SDL_GetThreadID(SDL_Thread * thread)
+SDL_threadID SDL_GetThreadID(SDL_Thread *thread)
 {
     SDL_threadID id;
 
@@ -446,8 +465,7 @@ SDL_GetThreadID(SDL_Thread * thread)
     return id;
 }
 
-const char *
-SDL_GetThreadName(SDL_Thread * thread)
+const char *SDL_GetThreadName(SDL_Thread *thread)
 {
     if (thread) {
         return thread->name;
@@ -456,14 +474,12 @@ SDL_GetThreadName(SDL_Thread * thread)
     }
 }
 
-int
-SDL_SetThreadPriority(SDL_ThreadPriority priority)
+int SDL_SetThreadPriority(SDL_ThreadPriority priority)
 {
     return SDL_SYS_SetThreadPriority(priority);
 }
 
-void
-SDL_WaitThread(SDL_Thread * thread, int *status)
+void SDL_WaitThread(SDL_Thread *thread, int *status)
 {
     if (thread) {
         SDL_SYS_WaitThread(thread);
@@ -477,8 +493,7 @@ SDL_WaitThread(SDL_Thread * thread, int *status)
     }
 }
 
-void
-SDL_DetachThread(SDL_Thread * thread)
+void SDL_DetachThread(SDL_Thread *thread)
 {
     if (!thread) {
         return;
@@ -491,9 +506,9 @@ SDL_DetachThread(SDL_Thread * thread)
         /* all other states are pretty final, see where we landed. */
         const int thread_state = SDL_AtomicGet(&thread->state);
         if ((thread_state == SDL_THREAD_STATE_DETACHED) || (thread_state == SDL_THREAD_STATE_CLEANED)) {
-            return;  /* already detached (you shouldn't call this twice!) */
+            return; /* already detached (you shouldn't call this twice!) */
         } else if (thread_state == SDL_THREAD_STATE_ZOMBIE) {
-            SDL_WaitThread(thread, NULL);  /* already done, clean it up. */
+            SDL_WaitThread(thread, NULL); /* already done, clean it up. */
         } else {
             SDL_assert(0 && "Unexpected thread state");
         }
