@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,7 +20,7 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_THREAD_PSP
+#ifdef SDL_THREAD_PSP
 
 /* Semaphore functions for the PSP. */
 
@@ -33,18 +33,18 @@
 #include <pspthreadman.h>
 #include <pspkerror.h>
 
-struct SDL_semaphore {
-    SceUID  semid;
+struct SDL_semaphore
+{
+    SceUID semid;
 };
 
-
 /* Create a semaphore */
 SDL_sem *SDL_CreateSemaphore(Uint32 initial_value)
 {
     SDL_sem *sem;
 
-    sem = (SDL_sem *) SDL_malloc(sizeof(*sem));
-    if (sem != NULL) {
+    sem = (SDL_sem *)SDL_malloc(sizeof(*sem));
+    if (sem) {
         /* TODO: Figure out the limit on the maximum value. */
         sem->semid = sceKernelCreateSema("SDL sema", 0, initial_value, 255, NULL);
         if (sem->semid < 0) {
@@ -62,7 +62,7 @@ SDL_sem *SDL_CreateSemaphore(Uint32 initial_value)
 /* Free the semaphore */
 void SDL_DestroySemaphore(SDL_sem *sem)
 {
-    if (sem != NULL) {
+    if (sem) {
         if (sem->semid > 0) {
             sceKernelDeleteSema(sem->semid);
             sem->semid = 0;
@@ -81,9 +81,8 @@ int SDL_SemWaitTimeout(SDL_sem *sem, Uint32 timeout)
     Uint32 *pTimeout;
     int res;
 
-    if (sem == NULL) {
-        SDL_InvalidParamError("sem");
-        return 0;
+    if (!sem) {
+        return SDL_InvalidParamError("sem");
     }
 
     if (timeout == 0) {
@@ -97,18 +96,18 @@ int SDL_SemWaitTimeout(SDL_sem *sem, Uint32 timeout)
     if (timeout == SDL_MUTEX_MAXWAIT) {
         pTimeout = NULL;
     } else {
-        timeout *= 1000;  /* Convert to microseconds. */
+        timeout *= 1000; /* Convert to microseconds. */
         pTimeout = &timeout;
     }
 
-    res = sceKernelWaitSema(sem->semid, 1, (SceUInt *) pTimeout);
-       switch (res) {
-               case SCE_KERNEL_ERROR_OK:
-                       return 0;
-               case SCE_KERNEL_ERROR_WAIT_TIMEOUT:
-                       return SDL_MUTEX_TIMEDOUT;
-               default:
-                       return SDL_SetError("sceKernelWaitSema() failed");
+    res = sceKernelWaitSema(sem->semid, 1, (SceUInt *)pTimeout);
+    switch (res) {
+    case SCE_KERNEL_ERROR_OK:
+        return 0;
+    case SCE_KERNEL_ERROR_WAIT_TIMEOUT:
+        return SDL_MUTEX_TIMEDOUT;
+    default:
+        return SDL_SetError("sceKernelWaitSema() failed");
     }
 }
 
@@ -127,7 +126,7 @@ Uint32 SDL_SemValue(SDL_sem *sem)
 {
     SceKernelSemaInfo info;
 
-    if (sem == NULL) {
+    if (!sem) {
         SDL_InvalidParamError("sem");
         return 0;
     }
@@ -143,7 +142,7 @@ int SDL_SemPost(SDL_sem *sem)
 {
     int res;
 
-    if (sem == NULL) {
+    if (!sem) {
         return SDL_InvalidParamError("sem");
     }
 
