@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2016 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -19,9 +19,8 @@
   3. This notice may not be removed or altered from any source distribution.
 */
 
-
-#ifndef _SDL_emscriptenevents_h
-#define _SDL_emscriptenevents_h
+#ifndef SDL_emscriptenevents_h_
+#define SDL_emscriptenevents_h_
 
 #include "SDL_emscriptenvideo.h"
 
@@ -30,7 +29,10 @@ Emscripten_RegisterEventHandlers(SDL_WindowData *data);
 
 extern void
 Emscripten_UnregisterEventHandlers(SDL_WindowData *data);
-#endif /* _SDL_emscriptenevents_h */
+
+extern EM_BOOL
+Emscripten_HandleCanvasResize(int eventType, const void *reserved, void *userData);
+
+#endif /* SDL_emscriptenevents_h_ */
 
 /* vi: set ts=4 sw=4 expandtab: */
-
