@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2016 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,10 +20,10 @@
 */
 #include "../../SDL_internal.h"
 
-#ifndef _SDL_vivanteplatform_h
-#define _SDL_vivanteplatform_h
+#ifndef SDL_vivanteplatform_h_
+#define SDL_vivanteplatform_h_
 
-#if SDL_VIDEO_DRIVER_VIVANTE
+#ifdef SDL_VIDEO_DRIVER_VIVANTE
 
 #include "SDL_vivantevideo.h"
 
@@ -36,10 +36,12 @@
 #endif
 
 extern int VIVANTE_SetupPlatform(_THIS);
+extern char *VIVANTE_GetDisplayName(_THIS);
+extern void VIVANTE_UpdateDisplayScale(_THIS);
 extern void VIVANTE_CleanupPlatform(_THIS);
 
 #endif /* SDL_VIDEO_DRIVER_VIVANTE */
 
-#endif /* _SDL_vivanteplatform_h */
+#endif /* SDL_vivanteplatform_h_ */
 
 /* vi: set ts=4 sw=4 expandtab: */
