@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,37 +20,34 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_WINDOWS && !defined(__XBOXONE__) && !defined(__XBOXSERIES__)
+#if defined(SDL_VIDEO_DRIVER_WINDOWS) && !defined(__XBOXONE__) && !defined(__XBOXSERIES__)
 
 #include "SDL_windowsvideo.h"
 #include "SDL_windowswindow.h"
+#include "SDL_timer.h"
 #include "../../events/SDL_clipboardevents_c.h"
 
-
 #ifdef UNICODE
-#define TEXT_FORMAT  CF_UNICODETEXT
+#define TEXT_FORMAT CF_UNICODETEXT
 #else
-#define TEXT_FORMAT  CF_TEXT
+#define TEXT_FORMAT CF_TEXT
 #endif
 
-
 /* Get any application owned window handle for clipboard association */
-static HWND
-GetWindowHandle(_THIS)
+static HWND GetWindowHandle(_THIS)
 {
     SDL_Window *window;
 
     window = _this->windows;
     if (window) {
-        return ((SDL_WindowData *) window->driverdata)->hwnd;
+        return ((SDL_WindowData *)window->driverdata)->hwnd;
     }
     return NULL;
 }
 
-int
-WIN_SetClipboardText(_THIS, const char *text)
+int WIN_SetClipboardText(_THIS, const char *text)
 {
-    SDL_VideoData *data = (SDL_VideoData *) _this->driverdata;
+    SDL_VideoData *data = (SDL_VideoData *)_this->driverdata;
     int result = 0;
 
     if (OpenClipboard(GetWindowHandle(_this))) {
@@ -66,12 +63,12 @@ WIN_SetClipboardText(_THIS, const char *text)
 
         /* Find out the size of the data */
         for (size = 0, i = 0; tstr[i]; ++i, ++size) {
-            if (tstr[i] == '\n' && (i == 0 || tstr[i-1] != '\r')) {
+            if (tstr[i] == '\n' && (i == 0 || tstr[i - 1] != '\r')) {
                 /* We're going to insert a carriage return */
                 ++size;
             }
         }
-        size = (size+1)*sizeof(*tstr);
+        size = (size + 1) * sizeof(*tstr);
 
         /* Save the data to the clipboard */
         hMem = GlobalAlloc(GMEM_MOVEABLE, size);
@@ -80,7 +77,7 @@ WIN_SetClipboardText(_THIS, const char *text)
             if (dst) {
                 /* Copy the text over, adding carriage returns as necessary */
                 for (i = 0; tstr[i]; ++i) {
-                    if (tstr[i] == '\n' && (i == 0 || tstr[i-1] != '\r')) {
+                    if (tstr[i] == '\n' && (i == 0 || tstr[i - 1] != '\r')) {
                         *dst++ = '\r';
                     }
                     *dst++ = tstr[i];
@@ -104,26 +101,33 @@ WIN_SetClipboardText(_THIS, const char *text)
     return result;
 }
 
-char *
-WIN_GetClipboardText(_THIS)
+char *WIN_GetClipboardText(_THIS)
 {
-    char *text;
+    char *text = NULL;
 
-    text = NULL;
-    if (IsClipboardFormatAvailable(TEXT_FORMAT) &&
-        OpenClipboard(GetWindowHandle(_this))) {
-        HANDLE hMem;
-        LPTSTR tstr;
+    if (IsClipboardFormatAvailable(TEXT_FORMAT)) {
+        /* Retry to open the clipboard in case another application has it open */
+        const int MAX_ATTEMPTS = 3;
+        int attempt;
 
-        hMem = GetClipboardData(TEXT_FORMAT);
-        if (hMem) {
-            tstr = (LPTSTR)GlobalLock(hMem);
-            text = WIN_StringToUTF8(tstr);
-            GlobalUnlock(hMem);
-        } else {
-            WIN_SetError("Couldn't get clipboard data");
+        for (attempt = 0; attempt < MAX_ATTEMPTS; ++attempt) {
+            if (OpenClipboard(GetWindowHandle(_this))) {
+                HANDLE hMem;
+                LPTSTR tstr;
+
+                hMem = GetClipboardData(TEXT_FORMAT);
+                if (hMem) {
+                    tstr = (LPTSTR)GlobalLock(hMem);
+                    text = WIN_StringToUTF8(tstr);
+                    GlobalUnlock(hMem);
+                } else {
+                    WIN_SetError("Couldn't get clipboard data");
+                }
+                CloseClipboard();
+                break;
+            }
+            SDL_Delay(10);
         }
-        CloseClipboard();
     }
     if (!text) {
         text = SDL_strdup("");
@@ -131,8 +135,7 @@ WIN_GetClipboardText(_THIS)
     return text;
 }
 
-SDL_bool
-WIN_HasClipboardText(_THIS)
+SDL_bool WIN_HasClipboardText(_THIS)
 {
     SDL_bool result = SDL_FALSE;
     char *text = WIN_GetClipboardText(_this);
@@ -143,8 +146,7 @@ WIN_HasClipboardText(_THIS)
     return result;
 }
 
-void
-WIN_CheckClipboardUpdate(struct SDL_VideoData * data)
+void WIN_CheckClipboardUpdate(struct SDL_VideoData *data)
 {
     const DWORD count = GetClipboardSequenceNumber();
     if (count != data->clipboard_count) {
