@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,27 +20,19 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_X11
+#ifdef SDL_VIDEO_DRIVER_X11
 
 #include <limits.h> /* For INT_MAX */
 
 #include "SDL_events.h"
 #include "SDL_x11video.h"
 #include "SDL_timer.h"
-
-
-/* If you don't support UTF-8, you might use XA_STRING here */
-#ifdef X_HAVE_UTF8_STRING
-#define TEXT_FORMAT X11_XInternAtom(display, "UTF8_STRING", False)
-#else
-#define TEXT_FORMAT XA_STRING
-#endif
+#include "SDL_x11clipboard.h"
 
 /* Get any application owned window handle for clipboard association */
-static Window
-GetWindow(_THIS)
+static Window GetWindow(_THIS)
 {
-    SDL_VideoData *data = (SDL_VideoData *) _this->driverdata;
+    SDL_VideoData *data = (SDL_VideoData *)_this->driverdata;
 
     /* We create an unmapped window that exists just to manage the clipboard,
        since X11 selection data is tied to a specific window and dies with it.
@@ -59,21 +51,74 @@ GetWindow(_THIS)
     return data->clipboard_window;
 }
 
-/* We use our own cut-buffer for intermediate storage instead of  
-   XA_CUT_BUFFER0 because their use isn't really defined for holding UTF8. */ 
-Atom
-X11_GetSDLCutBufferClipboardType(Display *display)
+/* We use our own cut-buffer for intermediate storage instead of
+   XA_CUT_BUFFER0 because their use isn't really defined for holding UTF8. */
+Atom X11_GetSDLCutBufferClipboardType(Display *display, enum ESDLX11ClipboardMimeType mime_type,
+                                      Atom selection_type)
 {
-    return X11_XInternAtom(display, "SDL_CUTBUFFER", False);
+    switch (mime_type) {
+    case SDL_X11_CLIPBOARD_MIME_TYPE_STRING:
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT_PLAIN:
+#ifdef X_HAVE_UTF8_STRING
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT_PLAIN_UTF8:
+#endif
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT:
+        return X11_XInternAtom(display, selection_type == XA_PRIMARY ? "SDL_CUTBUFFER_PRIMARY_SELECTION" : "SDL_CUTBUFFER",
+                               False);
+    default:
+        SDL_SetError("Can't find mime_type.");
+        return XA_STRING;
+    }
 }
 
-int
-X11_SetClipboardText(_THIS, const char *text)
+Atom X11_GetSDLCutBufferClipboardExternalFormat(Display *display, enum ESDLX11ClipboardMimeType mime_type)
 {
-    Display *display = ((SDL_VideoData *) _this->driverdata)->display;
-    Atom format;
+    switch (mime_type) {
+    case SDL_X11_CLIPBOARD_MIME_TYPE_STRING:
+/* If you don't support UTF-8, you might use XA_STRING here */
+#ifdef X_HAVE_UTF8_STRING
+        return X11_XInternAtom(display, "UTF8_STRING", False);
+#else
+        return XA_STRING;
+#endif
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT_PLAIN:
+        return X11_XInternAtom(display, "text/plain", False);
+#ifdef X_HAVE_UTF8_STRING
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT_PLAIN_UTF8:
+        return X11_XInternAtom(display, "text/plain;charset=utf-8", False);
+#endif
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT:
+        return X11_XInternAtom(display, "TEXT", False);
+    default:
+        SDL_SetError("Can't find mime_type.");
+        return XA_STRING;
+    }
+}
+Atom X11_GetSDLCutBufferClipboardInternalFormat(Display *display, enum ESDLX11ClipboardMimeType mime_type)
+{
+    switch (mime_type) {
+    case SDL_X11_CLIPBOARD_MIME_TYPE_STRING:
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT_PLAIN:
+#ifdef X_HAVE_UTF8_STRING
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT_PLAIN_UTF8:
+#endif
+    case SDL_X11_CLIPBOARD_MIME_TYPE_TEXT:
+/* If you don't support UTF-8, you might use XA_STRING here */
+#ifdef X_HAVE_UTF8_STRING
+        return X11_XInternAtom(display, "UTF8_STRING", False);
+#else
+        return XA_STRING;
+#endif
+    default:
+        SDL_SetError("Can't find mime_type.");
+        return XA_STRING;
+    }
+}
+
+static int SetSelectionText(_THIS, const char *text, Atom selection_type)
+{
+    Display *display = ((SDL_VideoData *)_this->driverdata)->display;
     Window window;
-    Atom XA_CLIPBOARD = X11_XInternAtom(display, "CLIPBOARD", 0);
 
     /* Get the SDL window that will own the selection */
     window = GetWindow(_this);
@@ -82,26 +127,18 @@ X11_SetClipboardText(_THIS, const char *text)
     }
 
     /* Save the selection on the root window */
-    format = TEXT_FORMAT;
     X11_XChangeProperty(display, DefaultRootWindow(display),
-        X11_GetSDLCutBufferClipboardType(display), format, 8, PropModeReplace,
-        (const unsigned char *)text, SDL_strlen(text));
+                        X11_GetSDLCutBufferClipboardType(display, SDL_X11_CLIPBOARD_MIME_TYPE_STRING, selection_type),
+                        X11_GetSDLCutBufferClipboardInternalFormat(display, SDL_X11_CLIPBOARD_MIME_TYPE_STRING), 8, PropModeReplace,
+                        (const unsigned char *)text, SDL_strlen(text));
 
-    if (XA_CLIPBOARD != None &&
-        X11_XGetSelectionOwner(display, XA_CLIPBOARD) != window) {
-        X11_XSetSelectionOwner(display, XA_CLIPBOARD, window, CurrentTime);
-    }
-
-    if (X11_XGetSelectionOwner(display, XA_PRIMARY) != window) {
-        X11_XSetSelectionOwner(display, XA_PRIMARY, window, CurrentTime);
-    }
+    X11_XSetSelectionOwner(display, selection_type, window, CurrentTime);
     return 0;
 }
 
-char *
-X11_GetClipboardText(_THIS)
+static char *GetSlectionText(_THIS, Atom selection_type)
 {
-    SDL_VideoData *videodata = (SDL_VideoData *) _this->driverdata;
+    SDL_VideoData *videodata = (SDL_VideoData *)_this->driverdata;
     Display *display = videodata->display;
     Atom format;
     Window window;
@@ -115,18 +152,13 @@ X11_GetClipboardText(_THIS)
     char *text;
     Uint32 waitStart;
     Uint32 waitElapsed;
-    Atom XA_CLIPBOARD = X11_XInternAtom(display, "CLIPBOARD", 0);
-    if (XA_CLIPBOARD == None) {
-        SDL_SetError("Couldn't access X clipboard");
-        return SDL_strdup("");
-    }
 
     text = NULL;
 
     /* Get the window that holds the selection */
     window = GetWindow(_this);
-    format = TEXT_FORMAT;
-    owner = X11_XGetSelectionOwner(display, XA_CLIPBOARD);
+    format = X11_GetSDLCutBufferClipboardInternalFormat(display, SDL_X11_CLIPBOARD_MIME_TYPE_STRING);
+    owner = X11_XGetSelectionOwner(display, selection_type);
     if (owner == None) {
         /* Fall back to ancient X10 cut-buffers which do not support UTF8 strings*/
         owner = DefaultRootWindow(display);
@@ -134,13 +166,13 @@ X11_GetClipboardText(_THIS)
         format = XA_STRING;
     } else if (owner == window) {
         owner = DefaultRootWindow(display);
-        selection = X11_GetSDLCutBufferClipboardType(display);
+        selection = X11_GetSDLCutBufferClipboardType(display, SDL_X11_CLIPBOARD_MIME_TYPE_STRING, selection_type);
     } else {
         /* Request that the selection owner copy the data to our window */
         owner = window;
         selection = X11_XInternAtom(display, "SDL_SELECTION", False);
-        X11_XConvertSelection(display, XA_CLIPBOARD, format, selection, owner,
-            CurrentTime);
+        X11_XConvertSelection(display, selection_type, format, selection, owner,
+                              CurrentTime);
 
         /* When using synergy on Linux and when data has been put in the clipboard
            on the remote (Windows anyway) machine then selection_waiting may never
@@ -150,23 +182,22 @@ X11_GetClipboardText(_THIS)
         while (videodata->selection_waiting) {
             SDL_PumpEvents();
             waitElapsed = SDL_GetTicks() - waitStart;
-            /* Wait one second for a clipboard response. */
+            /* Wait one second for a selection response. */
             if (waitElapsed > 1000) {
                 videodata->selection_waiting = SDL_FALSE;
-                SDL_SetError("Clipboard timeout");
-                /* We need to set the clipboard text so that next time we won't
+                SDL_SetError("Selection timeout");
+                /* We need to set the selection text so that next time we won't
                    timeout, otherwise we will hang on every call to this function. */
-                X11_SetClipboardText(_this, "");
+                SetSelectionText(_this, "", selection_type);
                 return SDL_strdup("");
             }
         }
     }
 
-    if (X11_XGetWindowProperty(display, owner, selection, 0, INT_MAX/4, False,
-            format, &seln_type, &seln_format, &nbytes, &overflow, &src)
-            == Success) {
+    if (X11_XGetWindowProperty(display, owner, selection, 0, INT_MAX / 4, False,
+                               format, &seln_type, &seln_format, &nbytes, &overflow, &src) == Success) {
         if (seln_type == format) {
-            text = (char *)SDL_malloc(nbytes+1);
+            text = (char *)SDL_malloc(nbytes + 1);
             if (text) {
                 SDL_memcpy(text, src, nbytes);
                 text[nbytes] = '\0';
@@ -182,8 +213,38 @@ X11_GetClipboardText(_THIS)
     return text;
 }
 
-SDL_bool
-X11_HasClipboardText(_THIS)
+int X11_SetClipboardText(_THIS, const char *text)
+{
+    SDL_VideoData *videodata = (SDL_VideoData *)_this->driverdata;
+    Atom XA_CLIPBOARD = X11_XInternAtom(videodata->display, "CLIPBOARD", 0);
+    if (XA_CLIPBOARD == None) {
+        return SDL_SetError("Couldn't access X clipboard");
+    }
+    return SetSelectionText(_this, text, XA_CLIPBOARD);
+}
+
+int X11_SetPrimarySelectionText(_THIS, const char *text)
+{
+    return SetSelectionText(_this, text, XA_PRIMARY);
+}
+
+char *X11_GetClipboardText(_THIS)
+{
+    SDL_VideoData *videodata = (SDL_VideoData *)_this->driverdata;
+    Atom XA_CLIPBOARD = X11_XInternAtom(videodata->display, "CLIPBOARD", 0);
+    if (XA_CLIPBOARD == None) {
+        SDL_SetError("Couldn't access X clipboard");
+        return SDL_strdup("");
+    }
+    return GetSlectionText(_this, XA_CLIPBOARD);
+}
+
+char *X11_GetPrimarySelectionText(_THIS)
+{
+    return GetSlectionText(_this, XA_PRIMARY);
+}
+
+SDL_bool X11_HasClipboardText(_THIS)
 {
     SDL_bool result = SDL_FALSE;
     char *text = X11_GetClipboardText(_this);
@@ -194,6 +255,17 @@ X11_HasClipboardText(_THIS)
     return result;
 }
 
+SDL_bool X11_HasPrimarySelectionText(_THIS)
+{
+    SDL_bool result = SDL_FALSE;
+    char *text = X11_GetPrimarySelectionText(_this);
+    if (text) {
+        result = text[0] != '\0' ? SDL_TRUE : SDL_FALSE;
+        SDL_free(text);
+    }
+    return result;
+}
+
 #endif /* SDL_VIDEO_DRIVER_X11 */
 
 /* vi: set ts=4 sw=4 expandtab: */
