@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,30 +20,24 @@
 */
 #include "../../SDL_internal.h"
 
-#if SDL_VIDEO_DRIVER_X11
+#ifdef SDL_VIDEO_DRIVER_X11
 
 #include "SDL_x11video.h"
 #include "SDL_x11touch.h"
 #include "SDL_x11xinput2.h"
 #include "../../events/SDL_touch_c.h"
 
-
-void
-X11_InitTouch(_THIS)
+void X11_InitTouch(_THIS)
 {
-    if (X11_Xinput2IsMultitouchSupported()) {
-        X11_InitXinput2Multitouch(_this);
-    }
+    X11_InitXinput2Multitouch(_this);
 }
 
-void
-X11_QuitTouch(_THIS)
+void X11_QuitTouch(_THIS)
 {
     SDL_TouchQuit();
 }
 
-void
-X11_ResetTouch(_THIS)
+void X11_ResetTouch(_THIS)
 {
     X11_QuitTouch(_this);
     X11_InitTouch(_this);
